"""Google address model."""

# pylint: disable=too-many-lines,line-too-long
import datetime
import logging
from collections import namedtuple
from typing import Any

import geocoder  # type: ignore
import pytest_is_running
import requests_cache
from timezonefinder import TimezoneFinder  # type: ignore

from ...cache import MEMORY
from ..address_model import AddressModel
from ..weather.multi_weather_model import create_mutli_weather_model

SportsballGeocodeTuple = namedtuple(
    "SportsballGeocodeTuple",
    ["city", "state", "postal", "lat", "lng", "housenumber", "country"],
)
LEVI_STADIUM = SportsballGeocodeTuple(
    city="Santa Clara",
    state="CA",
    postal="95054",
    lat=37.4033165,
    lng=-121.9719523,
    housenumber="4900",
    country="USA",
)
ARROWHEAD_STADIUM = SportsballGeocodeTuple(
    city="Kansas City",
    state="MO",
    postal="64129",
    lat=39.0489647,
    lng=-94.486589,
    housenumber="1",
    country="USA",
)
PAYCOR_STADIUM = SportsballGeocodeTuple(
    city="Cincinnati",
    state="OH",
    postal="45202",
    lat=39.0954576,
    lng=-84.5186326,
    housenumber="1",
    country="USA",
)
LUMEN_FIELD = SportsballGeocodeTuple(
    city="Seattle",
    state="WA",
    postal="98134",
    lat=47.5951518,
    lng=-122.3342143,
    housenumber="800",
    country="USA",
)
CAESARS_SUPERDOME = SportsballGeocodeTuple(
    city="New Orleans",
    state="LA",
    postal="70112",
    lat=29.951061,
    lng=-90.0838191,
    housenumber="1500",
    country="USA",
)
TOM_BENSON_HALL_OF_FAME_STADIUM = SportsballGeocodeTuple(
    city="Canton",
    state="OH",
    postal="44708",
    lat=40.8198713,
    lng=-81.4028911,
    housenumber="",
    country="USA",
)
GILETTE_STADIUM = SportsballGeocodeTuple(
    city="Foxborough",
    state="MA",
    postal="02035",
    lat=42.0909458,
    lng=-71.2669214,
    housenumber="1",
    country="USA",
)
FORD_FIELD = SportsballGeocodeTuple(
    city="Detroit",
    state="MI",
    postal="48226",
    lat=42.3400064,
    lng=-83.0481779,
    housenumber="2000",
    country="USA",
)
HARD_ROCK_STADIUM = SportsballGeocodeTuple(
    city="Miami Gardens",
    state="FL",
    postal="33056",
    lat=25.958326,
    lng=-80.2421728,
    housenumber="100",
    country="USA",
)
RAYMOND_JAMES_STADIUM = SportsballGeocodeTuple(
    city="Tampa",
    state="FL",
    postal="33607",
    lat=27.9758691,
    lng=-82.5059093,
    housenumber="4201",
    country="USA",
)
CLEVELAND_BROWNS_STADIUM = SportsballGeocodeTuple(
    city="Cleveland",
    state="OH",
    postal="44114",
    lat=41.5060535,
    lng=-81.702123,
    housenumber="100",
    country="USA",
)
STATE_FARM_STADIUM = SportsballGeocodeTuple(
    city="Glendale",
    state="AZ",
    postal="85305",
    lat=33.5276247,
    lng=-112.2651342,
    housenumber="1001",
    country="USA",
)
HIGHMARK_STADIUM = SportsballGeocodeTuple(
    city="Orchard Park",
    state="NY",
    postal="14127",
    lat=42.7737546,
    lng=-78.7895472,
    housenumber="1",
    country="USA",
)
SOLDIER_FIELD = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="60605",
    lat=41.8623132,
    lng=-87.6192633,
    housenumber="1410",
    country="USA",
)
BANK_OF_AMERICA_STADIUM = SportsballGeocodeTuple(
    city="Charlotte",
    state="NC",
    postal="28202",
    lat=35.2257795,
    lng=-80.8555399,
    housenumber="800",
    country="USA",
)
ATT_STADIUM = SportsballGeocodeTuple(
    city="Arlington",
    state="TX",
    postal="76011",
    lat=32.7479966,
    lng=-97.0959914,
    housenumber="1",
    country="USA",
)
MTT_BANK_STADIUM = SportsballGeocodeTuple(
    city="Baltimore",
    state="FL",
    postal="21230",
    lat=39.2778666,
    lng=-76.6255186,
    housenumber="101",
    country="USA",
)
SOFI_STADIUM = SportsballGeocodeTuple(
    city="Inglewood",
    state="CA",
    postal="90301",
    lat=33.9534651,
    lng=-118.3416145,
    housenumber="1001",
    country="USA",
)
ALLEGIANT_STADIUM = SportsballGeocodeTuple(
    city="Las Vegas",
    state="NV",
    postal="89118",
    lat=36.0908665,
    lng=-115.1858971,
    housenumber="3333",
    country="USA",
)
LINCOLN_FINANCIAL_FIELD = SportsballGeocodeTuple(
    city="Philadelphia",
    state="PA",
    postal="19148",
    lat=39.9013695,
    lng=-75.1700964,
    housenumber="",
    country="USA",
)
METLIFE_STADIUM = SportsballGeocodeTuple(
    city="East Rutherford",
    state="NJ",
    postal="07073",
    lat=40.8135064,
    lng=-74.0770319,
    housenumber="1",
    country="USA",
)
MERCEDES_BANZ_STADIUM = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="30313",
    lat=33.7553232,
    lng=-84.4031654,
    housenumber="1",
    country="USA",
)
NRG_STADIUM = SportsballGeocodeTuple(
    city="Houston",
    state="TX",
    postal="77054",
    lat=29.6847219,
    lng=-95.4132823,
    housenumber="",
    country="USA",
)
ACRISURE_STADIUM = SportsballGeocodeTuple(
    city="Pittsburgh",
    state="PA",
    postal="15212",
    lat=40.4467648,
    lng=-80.0183352,
    housenumber="100",
    country="USA",
)
LUCAS_OIL_STADIUM = SportsballGeocodeTuple(
    city="Indianapolis",
    state="IN",
    postal="46225",
    lat=39.7601007,
    lng=-86.1664626,
    housenumber="500",
    country="USA",
)
LAMBEAU_FIELD = SportsballGeocodeTuple(
    city="Green Bay",
    state="WI",
    postal="54304",
    lat=44.5013406,
    lng=-88.0647832,
    housenumber="1265",
    country="USA",
)
US_BANK_STADIUM = SportsballGeocodeTuple(
    city="Minneapolis",
    state="MN",
    postal="55415",
    lat=44.9736461,
    lng=-93.2600694,
    housenumber="401",
    country="USA",
)
FEDEX_FIELD = SportsballGeocodeTuple(
    city="Landover",
    state="MD",
    postal="20785",
    lat=38.9081324,
    lng=-76.8665633,
    housenumber="1600",
    country="USA",
)
NISSAN_STADIUM = SportsballGeocodeTuple(
    city="Nashville",
    state="TN",
    postal="37213",
    lat=36.166469,
    lng=-86.7738744,
    housenumber="1",
    country="USA",
)
EVERBANK_STADIUM = SportsballGeocodeTuple(
    city="Jacksonville",
    state="FL",
    postal="32202",
    lat=30.3239099,
    lng=-81.6399246,
    housenumber="1",
    country="USA",
)
EMPOWER_FIELD = SportsballGeocodeTuple(
    city="Denver",
    state="CO",
    postal="80204",
    lat=39.7438895,
    lng=-105.0226843,
    housenumber="1701",
    country="USA",
)
WEMBLEY_STADIUM = SportsballGeocodeTuple(
    city="Wembley",
    state="",
    postal="HA9 0WS",
    lat=51.5560247,
    lng=-0.2821926,
    housenumber="",
    country="UK",
)
TOTTENHAM_HOTSPURS_STADIUM = SportsballGeocodeTuple(
    city="London",
    state="",
    postal="N17 0BX",
    lat=51.6042204,
    lng=-0.071094,
    housenumber="782",
    country="UK",
)
DEUTSCHE_BANK_PARK = SportsballGeocodeTuple(
    city="Frankfurt am Main",
    state="",
    postal="60528",
    lat=50.0685807,
    lng=8.6428971,
    housenumber="362",
    country="Germany",
)
ALLIANZ_ARENA = SportsballGeocodeTuple(
    city="München",
    state="",
    postal="80939",
    lat=48.2187966,
    lng=11.6221325,
    housenumber="25",
    country="Germany",
)
GEORGIA_DOME = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="",
    lat=33.758,
    lng=-84.401,
    housenumber="1",
    country="USA",
)
TRANS_WORLD_DOME = SportsballGeocodeTuple(
    city="St. Louis",
    state="MO",
    postal="63101",
    lat=38.6328232,
    lng=-90.1910817,
    housenumber="701",
    country="USA",
)
CANDLESTICK_PARK = SportsballGeocodeTuple(
    city="San Francisco",
    state="CA",
    postal="94124",
    lat=37.7129826,
    lng=-122.4064101,
    housenumber="",
    country="USA",
)
SILVERDOME = SportsballGeocodeTuple(
    city="Pontiac",
    state="MI",
    postal="48342",
    lat=42.6456689,
    lng=-83.2572144,
    housenumber="",
    country="USA",
)
TEXAS_STADIUM = SportsballGeocodeTuple(
    city="Irving",
    state="TX",
    postal="",
    lat=32.839722,
    lng=-96.9146954,
    housenumber="",
    country="USA",
)
SDCCU_STADIUM = SportsballGeocodeTuple(
    city="San Diego",
    state="CA",
    postal="92108",
    lat=32.7809825,
    lng=-117.1244523,
    housenumber="9449",
    country="USA",
)
MOUNTAIN_AMERICA_STADIUM = SportsballGeocodeTuple(
    city="Tempe",
    state="AZ",
    postal="85287",
    lat=33.4264574,
    lng=-111.9374442,
    housenumber="500",
    country="USA",
)
LOS_ANGELES_MEMORIAL_COLESIUM = SportsballGeocodeTuple(
    city="Los Angeles",
    state="CA",
    postal="90037",
    lat=34.0136647,
    lng=-118.2904104,
    housenumber="3911",
    country="USA",
)
KEZAR_STADIUM = SportsballGeocodeTuple(
    city="San Francisco",
    state="CA",
    postal="94118",
    lat=37.7669182,
    lng=-122.4567445,
    housenumber="670",
    country="USA",
)
CITY_STADIUM = SportsballGeocodeTuple(
    city="Green Bay",
    state="WI",
    postal="54301",
    lat=44.5076658,
    lng=-87.9975486,
    housenumber="1500",
    country="USA",
)
COTTON_BOWL = SportsballGeocodeTuple(
    city="Dallas",
    state="TX",
    postal="75215",
    lat=32.7796106,
    lng=-96.7602328,
    housenumber="3750",
    country="USA",
)
WRIGLEY_FIELD = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="60613",
    lat=41.9484384,
    lng=-87.6579076,
    housenumber="1060",
    country="USA",
)
YANKEE_STADIUM = SportsballGeocodeTuple(
    city="Bronx",
    state="NY",
    postal="10451",
    lat=40.8296425,
    lng=-73.9310454,
    housenumber="1",
    country="USA",
)
TIGER_STADIUM = SportsballGeocodeTuple(
    city="Baton Rouge",
    state="LA",
    postal="70803",
    lat=30.412035,
    lng=-91.1863912,
    housenumber="",
    country="USA",
)
RFK_STADIUM = SportsballGeocodeTuple(
    city="Washington",
    state="DC",
    postal="20003",
    lat=38.8898525,
    lng=-76.9731573,
    housenumber="2400",
    country="USA",
)
WAR_MEMORIAL_STADIUM = SportsballGeocodeTuple(
    city="Little Rock",
    state="AR",
    postal="72205",
    lat=34.749861,
    lng=-92.3314143,
    housenumber="",
    country="USA",
)
SHEA_STADIUM = SportsballGeocodeTuple(
    city="Flushing",
    state="NY",
    postal="11368",
    lat=40.7570861,
    lng=-73.8653052,
    housenumber="41",
    country="USA",
)
MUNICIPAL_STADIUM = SportsballGeocodeTuple(
    city="Kansas City",
    state="MS",
    postal="",
    lat=39.087,
    lng=-94.558,
    housenumber="2123",
    country="USA",
)
YALE_BOWL = SportsballGeocodeTuple(
    city="New Haven",
    state="CT",
    postal="06515",
    lat=41.3132191,
    lng=-72.9630891,
    housenumber="81",
    country="USA",
)
RICE_STADIUM = SportsballGeocodeTuple(
    city="Houston",
    state="TX",
    postal="77005",
    lat=29.7162887,
    lng=-95.41188622,
    housenumber="6100",
    country="USA",
)
ROSE_BOWL = SportsballGeocodeTuple(
    city="Pasadena",
    state="CA",
    postal="91103",
    lat=34.1613284,
    lng=-118.1702211,
    housenumber="1001",
    country="USA",
)
MILWAUKEE_COUNTY_STADIUM = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="53208",
    lat=43.0303919,
    lng=-87.9787396,
    housenumber="201",
    country="USA",
)
STANFORD_STADIUM = SportsballGeocodeTuple(
    city="Stanford",
    state="CA",
    postal="94305",
    lat=37.4345298,
    lng=-122.1636976,
    housenumber="625",
    country="USA",
)
LIBERTY_BOWL_MEMORIAL_STADIUM = SportsballGeocodeTuple(
    city="Memphis",
    state="TN",
    postal="38119",
    lat=35.1213707,
    lng=-89.9969239,
    housenumber="959",
    country="USA",
)
NEO_QUIMICA_ARENA = SportsballGeocodeTuple(
    city="São Paulo",
    state="SP",
    postal="08295-005",
    lat=-23.5453134,
    lng=-46.4768041,
    housenumber="111",
    country="Brazil",
)
MCG = SportsballGeocodeTuple(
    city="Richmond",
    state="VIC",
    postal="3002",
    lat=-37.8199668,
    lng=144.9785784,
    housenumber="",
    country="USA",
)
SCG = SportsballGeocodeTuple(
    city="Moore Park",
    state="NSW",
    postal="2021",
    lat=-33.8915316,
    lng=151.2248515,
    housenumber="",
    country="Australia",
)
ENGIE_STADIUM = SportsballGeocodeTuple(
    city="Sydney Olympic Park",
    state="NSW",
    postal="2127",
    lat=-33.8471156,
    lng=151.0608386,
    housenumber="",
    country="Australia",
)
ADELAIDE_OVAL = SportsballGeocodeTuple(
    city="North Adelaide",
    state="SA",
    postal="5006",
    lat=-34.9156273,
    lng=138.5914356,
    housenumber="70",
    country="Australia",
)
GABBA = SportsballGeocodeTuple(
    city="Woolloongabba",
    state="QLD",
    postal="4102",
    lat=-27.4858375,
    lng=153.0332144,
    housenumber="",
    country="Australia",
)
OPTUS_STADIUM = SportsballGeocodeTuple(
    city="Burswood",
    state="WA",
    postal="6100",
    lat=-31.9511597,
    lng=115.884175,
    housenumber="333",
    country="Australia",
)
MARVEL_STADIUM = SportsballGeocodeTuple(
    city="Docklands",
    state="VIC",
    postal="3008",
    lat=-37.8165647,
    lng=144.9449306,
    housenumber="740",
    country="Australia",
)
MARS_STADIUM = SportsballGeocodeTuple(
    city="Wendouree",
    state="VIC",
    postal="3355",
    lat=-37.5386166,
    lng=143.8273839,
    housenumber="725",
    country="Australia",
)
GMHBA_STADIUM = SportsballGeocodeTuple(
    city="South Geelong",
    state="VIC",
    postal="3220",
    lat=-38.1579979,
    lng=144.3520981,
    housenumber="370",
    country="Australia",
)
UTAS_STADIUM = SportsballGeocodeTuple(
    city="Invermay",
    state="TAS",
    postal="7248",
    lat=-41.4259371,
    lng=147.137879,
    housenumber="2",
    country="Australia",
)
PEOPLE_FIRST_STADIUM = SportsballGeocodeTuple(
    city="Carrara",
    state="QLD",
    postal="4211",
    lat=-28.0063039,
    lng=153.3645259,
    housenumber="",
    country="Australia",
)
BLUNDSTONE_ARENA = SportsballGeocodeTuple(
    city="Bellerive",
    state="TAS",
    postal="7018",
    lat=-42.8772962,
    lng=147.3691419,
    housenumber="15",
    country="Australia",
)
MANUKA_OVAL = SportsballGeocodeTuple(
    city="Griffith",
    state="ACT",
    postal="2603",
    lat=-35.3181329,
    lng=149.1297911,
    housenumber="",
    country="Australia",
)
TIO_STADIUM = SportsballGeocodeTuple(
    city="Marrara",
    state="NT",
    postal="0812",
    lat=-12.3991939,
    lng=130.8847367,
    housenumber="70",
    country="Australia",
)
NORWOOD_OVAL = SportsballGeocodeTuple(
    city="Norwood",
    state="SA",
    postal="5067",
    lat=-34.9198089,
    lng=138.6278735,
    housenumber="",
    country="Australia",
)
ADELAIDE_HILLS = SportsballGeocodeTuple(
    city="Mount Barker Summit",
    state="SA",
    postal="5251",
    lat=-35.0779754,
    lng=138.8908443,
    housenumber="304",
    country="Australia",
)
TRAEGER_PARK = SportsballGeocodeTuple(
    city="The Gap",
    state="NT",
    postal="0870",
    lat=-23.7090566,
    lng=133.8701488,
    housenumber="",
    country="Australia",
)
CAZALYS_STADIUM = SportsballGeocodeTuple(
    city="Westcourt",
    state="QLD",
    postal="4870",
    lat=-16.9357343,
    lng=145.7464957,
    housenumber="",
    country="Australia",
)
RIVERWAY_STADIUM = SportsballGeocodeTuple(
    city="Thuringowa Central",
    state="QLD",
    postal="4817",
    lat=-19.3176321,
    lng=146.7270047,
    housenumber="",
    country="Australia",
)
JIANGWAN_STADIUM = SportsballGeocodeTuple(
    city="Shanghai",
    state="",
    postal="200433",
    lat=31.3076026,
    lng=121.5160351,
    housenumber="",
    country="China",
)
DOMAIN_STADIUM = SportsballGeocodeTuple(
    city="Subiaco",
    state="WA",
    postal="6008",
    lat=-31.9444594,
    lng=115.8285952,
    housenumber="304",
    country="Australia",
)
WESTPAC_STADIUM = SportsballGeocodeTuple(
    city="Pipitea",
    state="",
    postal="6140",
    lat=-41.2729198,
    lng=174.7846279,
    housenumber="105",
    country="New Zealand",
)
AAMI_STADIUM = SportsballGeocodeTuple(
    city="West Lakes",
    state="SA",
    postal="5021",
    lat=-34.8797138,
    lng=138.4910204,
    housenumber="",
    country="Australia",
)
BLACKTOWN_PARK = SportsballGeocodeTuple(
    city="Rooty Hill",
    state="NSW",
    postal="2766",
    lat=-33.7695492,
    lng=150.8558658,
    housenumber="",
    country="Australia",
)
PITBULL_STADIUM = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="33199",
    lat=25.7525,
    lng=-80.377778,
    housenumber="11200",
    country="USA",
)
LANNY_AND_SHARON_MARTIN_STADIUM = SportsballGeocodeTuple(
    city="Evanston",
    state="IL",
    postal="60208",
    lat=42.0584293,
    lng=-87.6707798,
    housenumber="2235",
    country="USA",
)
MIAMI_ORANGE_BOWL = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="33125",
    lat=25.7781487,
    lng=-80.2221747,
    housenumber="501",
    country="USA",
)
SPECTRUM = SportsballGeocodeTuple(
    city="Philadelphia",
    state="PA",
    postal="",
    lat=39.901111,
    lng=-75.171944,
    housenumber="3601",
    country="USA",
)
MADISON_SQUARE_GARDEN = SportsballGeocodeTuple(
    city="New York",
    state="NY",
    postal="",
    lat=40.750556,
    lng=-73.993611,
    housenumber="4",
    country="USA",
)
MILWAUKEE_ARENA = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="",
    lat=43.042222,
    lng=-87.916944,
    housenumber="400",
    country="USA",
)
THE_FORUM = SportsballGeocodeTuple(
    city="Inglewood",
    state="CA",
    postal="",
    lat=33.958333,
    lng=-118.341667,
    housenumber="3900",
    country="USA",
)
AMERICA_WEST_ARENA = SportsballGeocodeTuple(
    city="Phoenix",
    state="AZ",
    postal="",
    lat=33.445833,
    lng=-112.071389,
    housenumber="201",
    country="USA",
)
ALAMODOME = SportsballGeocodeTuple(
    city="San Antonio",
    state="TX",
    postal="78203",
    lat=29.416944,
    lng=-98.478889,
    housenumber="100",
    country="USA",
)
AMERICAN_AIRLINES_ARENA = SportsballGeocodeTuple(
    city="Dallas",
    state="TX",
    postal="",
    lat=32.790556,
    lng=-96.810278,
    housenumber="2500",
    country="USA",
)
THOMAS_AND_MACK_CENTER = SportsballGeocodeTuple(
    city="Las Vegas",
    state="NV",
    postal="",
    lat=36.105,
    lng=-115.144167,
    housenumber="4505",
    country="USA",
)
ORLANDO_ARENA = SportsballGeocodeTuple(
    city="Orlando",
    state="FL",
    postal="32801",
    lat=28.548889,
    lng=-81.386667,
    housenumber="600",
    country="USA",
)
TD_GARDEN = SportsballGeocodeTuple(
    city="Boston",
    state="MA",
    postal="",
    lat=42.366303,
    lng=-71.062228,
    housenumber="100",
    country="USA",
)
STATE_FARM_ARENA = SportsballGeocodeTuple(
    city="Atlanta",
    state="GA",
    postal="",
    lat=33.757222,
    lng=-84.396389,
    housenumber="1",
    country="USA",
)
PEPSI_CENTRE = SportsballGeocodeTuple(
    city="Denver",
    state="CO",
    postal="",
    lat=39.748611,
    lng=-105.0075,
    housenumber="1000",
    country="USA",
)
GAINBRIDGE_FIELDHOUSE = SportsballGeocodeTuple(
    city="Indianapolis",
    state="IN",
    postal="",
    lat=39.763889,
    lng=-86.155556,
    housenumber="125",
    country="USA",
)
FISERV_FORUM = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="",
    lat=43.045028,
    lng=-87.918167,
    housenumber="1111",
    country="USA",
)
STAPLES_CENTRE = SportsballGeocodeTuple(
    city="Los Angeles",
    state="CA",
    postal="90015",
    lat=34.0429909,
    lng=-118.2673753,
    housenumber="1111",
    country="USA",
)
UNITED_CENTER = SportsballGeocodeTuple(
    city="Chicago",
    state="IL",
    postal="",
    lat=41.880556,
    lng=-87.674167,
    housenumber="1901",
    country="USA",
)
FEDEX_FORUM = SportsballGeocodeTuple(
    city="Memphis",
    state="TN",
    postal="",
    lat=35.138333,
    lng=-90.050556,
    housenumber="191",
    country="USA",
)
TARGET_CENTER = SportsballGeocodeTuple(
    city="Minneapolis",
    state="MN",
    postal="",
    lat=44.979444,
    lng=-93.276111,
    housenumber="600",
    country="USA",
)
GOLDEN_1_CENTER = SportsballGeocodeTuple(
    city="Sacramento",
    state="CA",
    postal="",
    lat=38.580361,
    lng=-121.499611,
    housenumber="500",
    country="USA",
)
DELTA_CENTER = SportsballGeocodeTuple(
    city="Salt Lake City",
    state="UT",
    postal="",
    lat=40.768333,
    lng=-111.901111,
    housenumber="301",
    country="USA",
)
ATT_CENTER = SportsballGeocodeTuple(
    city="San Antonio",
    state="TX",
    postal="",
    lat=29.426944,
    lng=-98.4375,
    housenumber="1",
    country="USA",
)
FTX_ARENA = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="",
    lat=25.781389,
    lng=-80.188056,
    housenumber="601",
    country="USA",
)
VIVINT_ARENA = SportsballGeocodeTuple(
    city="Salt Lake City",
    state="UT",
    postal="",
    lat=40.768333,
    lng=-111.901111,
    housenumber="301",
    country="USA",
)
CHESAPEAKE_ENERGY_ARENA = SportsballGeocodeTuple(
    city="Oklahoma City",
    state="OK",
    postal="",
    lat=35.463333,
    lng=-97.515,
    housenumber="100",
    country="USA",
)
ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX = SportsballGeocodeTuple(
    city="Lake Buena Vista",
    state="FL",
    postal="32830",
    lat=28.337083,
    lng=-81.556,
    housenumber="1375",
    country="USA",
)
QUICKEN_LOANS_ARENA = SportsballGeocodeTuple(
    city="Cleveland",
    state="OH",
    postal="",
    lat=41.496389,
    lng=-81.688056,
    housenumber="1",
    country="USA",
)
KASEYA_CENTER = SportsballGeocodeTuple(
    city="Miami",
    state="FL",
    postal="",
    lat=25.781389,
    lng=-80.188056,
    housenumber="601",
    country="USA",
)
DUNN_OLIVER_ACADOME = SportsballGeocodeTuple(
    city="Montgomery",
    state="AL",
    postal="",
    lat=32.36185,
    lng=-86.293158,
    housenumber="",
    country="USA",
)
OAKLAND_ARENA = SportsballGeocodeTuple(
    city="Oakland",
    state="CA",
    postal="",
    lat=37.750278,
    lng=-122.203056,
    housenumber="7000",
    country="USA",
)
SCOTIABANK_ARENA = SportsballGeocodeTuple(
    city="Toronto",
    state="ON",
    postal="",
    lat=43.643333,
    lng=-79.379167,
    housenumber="40",
    country="Canada",
)
BRADLEY_CENTER = SportsballGeocodeTuple(
    city="Milwaukee",
    state="WI",
    postal="",
    lat=43.043611,
    lng=-87.916944,
    housenumber="1001",
    country="USA",
)
THE_PIT = SportsballGeocodeTuple(
    city="Albuquerque",
    state="NM",
    postal="",
    lat=35.067,
    lng=-106.632,
    housenumber="",
    country="USA",
)
JOHN_GLASER_ARENA = SportsballGeocodeTuple(
    city="Philadelphia",
    state="PA",
    postal="19141",
    lat=40.039993,
    lng=-75.15654,
    housenumber="15",
    country="USA",
)
TEXAS_AM_COMMERCE_FIELD_HOUSE = SportsballGeocodeTuple(
    city="Commerce",
    state="TX",
    postal="75428",
    lat=33.245337,
    lng=-95.907619,
    housenumber="2600",
    country="USA",
)
_CACHED_GEOCODES: dict[str, Any] = {
    "S.C.G. - Australia": SCG,
    "Victoria Park - Australia": SportsballGeocodeTuple(
        city="Abbotsford",
        state="VIC",
        postal="3067",
        lat=-37.8105167,
        lng=144.9822987,
        housenumber="",
        country="Australia",
    ),
    "Tom Benson Hall of Fame Stadium": TOM_BENSON_HALL_OF_FAME_STADIUM,
    "MetLife Stadium": METLIFE_STADIUM,
    "Gillette Stadium": GILETTE_STADIUM,
    "Acrisure Stadium": ACRISURE_STADIUM,
    "Hard Rock Stadium": HARD_ROCK_STADIUM,
    "M&T Bank Stadium": MTT_BANK_STADIUM,
    "Highmark Stadium": HIGHMARK_STADIUM,
    "U.S. Bank Stadium": US_BANK_STADIUM,
    "Cleveland Browns Stadium": CLEVELAND_BROWNS_STADIUM,
    "EverBank Stadium": EVERBANK_STADIUM,
    "Nissan Stadium": NISSAN_STADIUM,
    "Paycor Stadium": PAYCOR_STADIUM,
    "SoFi Stadium": SOFI_STADIUM,
    "State Farm Stadium": STATE_FARM_STADIUM,
    "Lucas Oil Stadium": LUCAS_OIL_STADIUM,
    "NRG Stadium": NRG_STADIUM,
    "Soldier Field": SOLDIER_FIELD,
    "GEHA Field at Arrowhead Stadium": ARROWHEAD_STADIUM,
    "Bank of America Stadium": BANK_OF_AMERICA_STADIUM,
    "Allegiant Stadium": ALLEGIANT_STADIUM,
    "Empower Field at Mile High": EMPOWER_FIELD,
    "Levi's Stadium": LEVI_STADIUM,
    "Mercedes-Benz Stadium": MERCEDES_BANZ_STADIUM,
    "Raymond James Stadium": RAYMOND_JAMES_STADIUM,
    "Lambeau Field": LAMBEAU_FIELD,
    "Lincoln Financial Field": LINCOLN_FINANCIAL_FIELD,
    "Ford Field": FORD_FIELD,
    "AT&T Stadium": ATT_STADIUM,
    "Lumen Field": LUMEN_FIELD,
    "Caesars Superdome": CAESARS_SUPERDOME,
    "Neo Química Arena": NEO_QUIMICA_ARENA,
    "FedExField": FEDEX_FIELD,
    "Tottenham Hotspur Stadium": TOTTENHAM_HOTSPURS_STADIUM,
    "Wembley Stadium": WEMBLEY_STADIUM,
    "Allianz Arena": ALLIANZ_ARENA,
    "Levi Stadium": LEVI_STADIUM,
    "Levi’s Stadium": LEVI_STADIUM,
    "Deutsche Bank Park": DEUTSCHE_BANK_PARK,
    "Arrowhead Stadium": ARROWHEAD_STADIUM,
    "Paul Brown Stadium": PAYCOR_STADIUM,
    "Trans World Dome": TRANS_WORLD_DOME,
    "Kingdome": LUMEN_FIELD,
    "Georgia Dome": GEORGIA_DOME,
    "Louisiana Superdome": CAESARS_SUPERDOME,
    "Tom Benson Hall of Fame Stadium - Canton - OH - 44708": TOM_BENSON_HALL_OF_FAME_STADIUM,
    "Gillette Stadium - Foxborough - MA - 02035": GILETTE_STADIUM,
    "Lumen Field - Seattle - WA - 98134": LUMEN_FIELD,
    "Paycor Stadium - Cincinnati - OH - 45202": PAYCOR_STADIUM,
    "Ford Field - Detroit - MI - 48226": FORD_FIELD,
    "Hard Rock Stadium - Miami Gardens - FL - 33056": HARD_ROCK_STADIUM,
    "Raymond James Stadium - Tampa - FL - 33607": RAYMOND_JAMES_STADIUM,
    "Huntington Bank Field - Cleveland - OH - 44114": CLEVELAND_BROWNS_STADIUM,
    "State Farm Stadium - Glendale - AZ - 85305": STATE_FARM_STADIUM,
    "Highmark Stadium - Orchard Park - NY - 14127": HIGHMARK_STADIUM,
    "Soldier Field - Chicago - IL - 60605": SOLDIER_FIELD,
    "Bank of America Stadium - Charlotte - NC - 28202": BANK_OF_AMERICA_STADIUM,
    "AT&T Stadium - Arlington - TX - 76011": ATT_STADIUM,
    "M&T Bank Stadium - Baltimore - MD - 21230": MTT_BANK_STADIUM,
    "SoFi Stadium - Inglewood - CA - 90301": SOFI_STADIUM,
    "Caesars Superdome - New Orleans - LA - 70112": CAESARS_SUPERDOME,
    "Allegiant Stadium - Las Vegas - NV - 89118": ALLEGIANT_STADIUM,
    "Lincoln Financial Field - Philadelphia - PA - 19148": LINCOLN_FINANCIAL_FIELD,
    "MetLife Stadium - East Rutherford - NJ - 07073": METLIFE_STADIUM,
    "Mercedes-Benz Stadium - Atlanta - GA - 30313": MERCEDES_BANZ_STADIUM,
    "NRG Stadium - Houston - TX - 77054": NRG_STADIUM,
    "Acrisure Stadium - Pittsburgh - PA - 15212": ACRISURE_STADIUM,
    "Lucas Oil Stadium - Indianapolis - IN - 46225": LUCAS_OIL_STADIUM,
    "Lambeau Field - Green Bay - WI - 54304": LAMBEAU_FIELD,
    "U.S. Bank Stadium - Minneapolis - MN - 55415": US_BANK_STADIUM,
    "Levi's Stadium - Santa Clara - CA - 95054": LEVI_STADIUM,
    "Northwest Stadium - Landover - MD - 20785": FEDEX_FIELD,
    "Nissan Stadium - Nashville - TN - 37213": NISSAN_STADIUM,
    "GEHA Field at Arrowhead Stadium - Kansas City - MO - 64129": ARROWHEAD_STADIUM,
    "EverBank Stadium - Jacksonville - FL - 32202": EVERBANK_STADIUM,
    "Empower Field at Mile High - Denver - CO - 80204": EMPOWER_FIELD,
    "Brunswick St - Australia": SportsballGeocodeTuple(
        city="Fitzroy North",
        state="VIC",
        postal="3068",
        lat=-37.7891016,
        lng=144.9759327,
        housenumber="1",
        country="Australia",
    ),
    "Corio Oval - Australia": SportsballGeocodeTuple(
        city="East Geelong",
        state="VIC",
        postal="3219",
        lat=-38.1525822,
        lng=144.3787522,
        housenumber="5",
        country="Australia",
    ),
    "Lake Oval - Australia": SportsballGeocodeTuple(
        city="Albert Park",
        state="VIC",
        postal="3206",
        lat=-37.8403445,
        lng=144.9458567,
        housenumber="",
        country="Australia",
    ),
    "East Melbourne - Australia": SportsballGeocodeTuple(
        city="Richmond",
        state="VIC",
        postal="3002",
        lat=-37.8174763,
        lng=144.9777351,
        housenumber="",
        country="Australia",
    ),
    "Junction Oval - Australia": SportsballGeocodeTuple(
        city="St Kilda",
        state="VIC",
        postal="3182",
        lat=-37.8559698,
        lng=144.9779958,
        housenumber="",
        country="Australia",
    ),
    "M.C.G. - Australia": MCG,
    "Princes Park - Australia": SportsballGeocodeTuple(
        city="Carlton North",
        state="VIC",
        postal="3054",
        lat=-37.7849821,
        lng=144.9565047,
        housenumber="200-590",
        country="Australia",
    ),
    "Wembley Stadium - London": WEMBLEY_STADIUM,
    "Tottenham Hotspur Stadium - London": TOTTENHAM_HOTSPURS_STADIUM,
    "Punt Rd - Australia": SportsballGeocodeTuple(
        city="East Melbourne",
        state="VIC",
        postal="3002",
        lat=-37.8222208,
        lng=144.9856865,
        housenumber="",
        country="Australia",
    ),
    "Frankfurt Stadium - Frankfurt": DEUTSCHE_BANK_PARK,
    "Windy Hill - Australia": SportsballGeocodeTuple(
        city="Essendon",
        state="VIC",
        postal="3040",
        lat=-37.7515878,
        lng=144.9001347,
        housenumber="",
        country="Australia",
    ),
    "Camping World Stadium - Orlando - FL - 32805": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="32805",
        lat=28.5390192,
        lng=-81.4033962,
        housenumber="1",
        country="USA",
    ),
    "Allianz Arena - Munich": ALLIANZ_ARENA,
    "Estadio Azteca - Mexico City": SportsballGeocodeTuple(
        city="Ciudad de México",
        state="CDMX",
        postal="04650",
        lat=19.3028606,
        lng=-99.1553986,
        housenumber="3465",
        country="Mexico",
    ),
    "Glenferrie Oval - Australia": SportsballGeocodeTuple(
        city="Hawthorn",
        state="VIC",
        postal="3122",
        lat=-37.8206183,
        lng=145.0303644,
        housenumber="34",
        country="Australia",
    ),
    "Dignity Health Sports Park - Carson - CA - 90746": SportsballGeocodeTuple(
        city="Carson",
        state="CA",
        postal="90746",
        lat=33.8643776,
        lng=-118.2660135,
        housenumber="18400",
        country="USA",
    ),
    "Arden St - Australia": SportsballGeocodeTuple(
        city="North Melbourne",
        state="VIC",
        postal="3051",
        lat=-37.7989787,
        lng=144.9388898,
        housenumber="204-206",
        country="Australia",
    ),
    "Oakland Coliseum - Oakland - CA - 94621": SportsballGeocodeTuple(
        city="Oakland",
        state="CA",
        postal="94621",
        lat=37.7514142,
        lng=-122.2034855,
        housenumber="204-206",
        country="USA",
    ),
    "Los Angeles Memorial Coliseum - Los Angeles - CA - 90037": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Western Oval - Australia": SportsballGeocodeTuple(
        city="Parkville",
        state="VIC",
        postal="3052",
        lat=-37.7781687,
        lng=144.9505349,
        housenumber="",
        country="Australia",
    ),
    "Twickenham Stadium - London": SportsballGeocodeTuple(
        city="Twickenham",
        state="",
        postal="TW2 7BA",
        lat=51.4559558,
        lng=-0.34408,
        housenumber="200",
        country="UK",
    ),
    "Olympic Park - Australia": SportsballGeocodeTuple(
        city="Heidelberg West",
        state="VIC",
        postal="3081",
        lat=-37.7397886,
        lng=145.0317471,
        housenumber="",
        country="Australia",
    ),
    "Georgia Dome - Atlanta - GA": GEORGIA_DOME,
    "SDCCU Stadium - San Diego - CA": SDCCU_STADIUM,
    "Kardinia Park - Australia": GMHBA_STADIUM,
    "The Dome at America's Center - St. Louis - MO - 63101": TRANS_WORLD_DOME,
    "Huntington Bank Stadium - Minneapolis - MN - 55455": US_BANK_STADIUM,
    "Yarraville Oval - Australia": SportsballGeocodeTuple(
        city="Yarraville",
        state="VIC",
        postal="3013",
        lat=-37.8150875,
        lng=144.8824932,
        housenumber="",
        country="Australia",
    ),
    "Candlestick Park - San Francisco - CA": CANDLESTICK_PARK,
    "Mall of America Field - Minneapolis - MN - 55415": US_BANK_STADIUM,
    "Toorak Park - Australia": SportsballGeocodeTuple(
        city="Armadale",
        state="VIC",
        postal="3143",
        lat=-37.8528107,
        lng=145.0114987,
        housenumber="580",
        country="Australia",
    ),
    "Rogers Centre - Toronto - ON": SportsballGeocodeTuple(
        city="Toronto",
        state="ON",
        postal="M5V 1J1",
        lat=43.6415757,
        lng=-79.3942991,
        housenumber="580",
        country="Canada",
    ),
    "Euroa - Australia": SportsballGeocodeTuple(
        city="Euroa",
        state="VIC",
        postal="3666",
        lat=-36.7464868,
        lng=145.5724273,
        housenumber="",
        country="Australia",
    ),
    "Aloha Stadium - Honolulu - HI - 96818": SportsballGeocodeTuple(
        city="Aiea",
        state="HI",
        postal="96701",
        lat=21.3728016,
        lng=-157.9348645,
        housenumber="99-500",
        country="USA",
    ),
    "Giants Stadium - East Rutherford - NJ": METLIFE_STADIUM,
    "Metrodome - Minneapolis - MN - 55415": US_BANK_STADIUM,
    "North Hobart - Australia": SportsballGeocodeTuple(
        city="North Hobart",
        state="TAS",
        postal="7000",
        lat=-42.8682555,
        lng=147.3146486,
        housenumber="1-5",
        country="Australia",
    ),
    "Texas Stadium - Irving - TX": TEXAS_STADIUM,
    "Yallourn - Australia": SportsballGeocodeTuple(
        city="Yallourn North",
        state="VIC",
        postal="3825",
        lat=-38.1629374,
        lng=146.3595115,
        housenumber="",
        country="Australia",
    ),
    "Albury - Australia": SportsballGeocodeTuple(
        city="Hamilton Valley",
        state="NSW",
        postal="2641",
        lat=-36.0349793,
        lng=146.9073391,
        housenumber="1",
        country="Australia",
    ),
    "Invesco Field - Denver - CO - 80804": EMPOWER_FIELD,
    "Brisbane Exhibition - Australia": SportsballGeocodeTuple(
        city="Bowen Hills",
        state="QLD",
        postal="4006",
        lat=-27.4503048,
        lng=153.0301872,
        housenumber="600",
        country="Australia",
    ),
    "Monster Park - San Francisco - CA - 94124": CANDLESTICK_PARK,
    "RCA Dome - Indianapolis - IN": LUCAS_OIL_STADIUM,
    "Mountain America Stadium - Tempe - AZ - 85287": MOUNTAIN_AMERICA_STADIUM,
    "Veterans Stadium - Philadelphia - PA": LINCOLN_FINANCIAL_FIELD,
    "Silverdome - Pontiac - MI": SILVERDOME,
    "Giants Stadium": METLIFE_STADIUM,
    "Mile High Stadium": EMPOWER_FIELD,
    "Pontiac Silverdome": SILVERDOME,
    "Foxboro Stadium": GILETTE_STADIUM,
    "Veterans Stadium": LINCOLN_FINANCIAL_FIELD,
    "Texas Stadium": TEXAS_STADIUM,
    "Three Rivers Stadium": ACRISURE_STADIUM,
    "Qualcomm Stadium": SDCCU_STADIUM,
    "Sun Devil Stadium": MOUNTAIN_AMERICA_STADIUM,
    "Three Rivers Stadium - Pittsburgh - PA": ACRISURE_STADIUM,
    "Moorabbin Oval - Australia": SportsballGeocodeTuple(
        city="Moorabbin",
        state="VIC",
        postal="3189",
        lat=-37.9371257,
        lng=145.0404112,
        housenumber="3",
        country="Australia",
    ),
    "Vanderbilt Stadium": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37212",
        lat=36.1438701,
        lng=-86.8284249,
        housenumber="",
        country="USA",
    ),
    "Liberty Bowl Memorial Stadium": LIBERTY_BOWL_MEMORIAL_STADIUM,
    "RFK Stadium": RFK_STADIUM,
    "Astrodome": NRG_STADIUM,
    "Cleveland Municipal Stadium": CLEVELAND_BROWNS_STADIUM,
    "Riverfront Stadium": PAYCOR_STADIUM,
    "Candlestick Park": CANDLESTICK_PARK,
    "Los Angeles Memorial Coliseum": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Coburg Oval - Australia": SportsballGeocodeTuple(
        city="Coburg",
        state="VIC",
        postal="3058",
        lat=-37.7437207,
        lng=144.9671031,
        housenumber="",
        country="Australia",
    ),
    "Waverley Park - Australia": SportsballGeocodeTuple(
        city="Mulgrave",
        state="VIC",
        postal="3170",
        lat=-37.9258818,
        lng=145.1869239,
        housenumber="2A",
        country="Australia",
    ),
    "Rose Bowl": ROSE_BOWL,
    "Miami Orange Bowl": MIAMI_ORANGE_BOWL,
    "Stanford Stadium": STANFORD_STADIUM,
    "Milwaukee County Stadium": MILWAUKEE_COUNTY_STADIUM,
    "Shea Stadium": SHEA_STADIUM,
    "Schaefer Stadium": GILETTE_STADIUM,
    "Yale Bowl": YALE_BOWL,
    "Tiger Stadium": TIGER_STADIUM,
    "War Memorial Stadium": WAR_MEMORIAL_STADIUM,
    "Yankee Stadium": YANKEE_STADIUM,
    "Municipal Stadium": MUNICIPAL_STADIUM,
    "Cotton Bowl": COTTON_BOWL,
    "Kezar Stadium": KEZAR_STADIUM,
    "Franklin Field": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19104",
        lat=39.9502158,
        lng=-75.1949801,
        housenumber="235",
        country="USA",
    ),
    "Wrigley Field": WRIGLEY_FIELD,
    "City Stadium": CITY_STADIUM,
    "IG Field - Winnipeg - MB": SportsballGeocodeTuple(
        city="Winnipeg",
        state="MB",
        postal="R3T 1Z2",
        lat=49.8077033,
        lng=-97.1456866,
        housenumber="315",
        country="Canada",
    ),
    "Subiaco - Australia": DOMAIN_STADIUM,
    "Rice Stadium": RICE_STADIUM,
    "Gabba - Australia": GABBA,
    "Independence Stadium - 71109": SportsballGeocodeTuple(
        city="Shreveport",
        state="LA",
        postal="71109",
        lat=32.475745,
        lng=-93.7944423,
        housenumber="3301",
        country="USA",
    ),
    "Carrara - Australia": PEOPLE_FIRST_STADIUM,
    "W.A.C.A. - Australia": SportsballGeocodeTuple(
        city="East Perth",
        state="WA",
        postal="6004",
        lat=-31.959812,
        lng=115.874661,
        housenumber="",
        country="Australia",
    ),
    "Los Angeles Memorial Coliseum - Los Angeles, California - United States": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Memorial Stadium (Lincoln) - Terre Haute, Indiana, USA - United States": SportsballGeocodeTuple(
        city="Lincoln",
        state="NE",
        postal="68588",
        lat=40.8206975,
        lng=-96.7081629,
        housenumber="1",
        country="USA",
    ),
    "Kezar Stadium - San Francisco, California - United States": KEZAR_STADIUM,
    "Cotton Bowl - Dallas, Texas - United States": COTTON_BOWL,
    "Wrigley Field - Chicago, Illinois - United States": WRIGLEY_FIELD,
    "Yankee Stadium - Bronx, New York - United States": YANKEE_STADIUM,
    "Tiger Stadium - Baton Rouge, Louisiana, USA - United States": TIGER_STADIUM,
    "Lambeau Field - Green Bay, Wisconsin - United States": LAMBEAU_FIELD,
    "RFK Stadium - Washington DC - United States": RFK_STADIUM,
    "War Memorial Stadium - Little Rock, Arkansas - United States": WAR_MEMORIAL_STADIUM,
    "Three Rivers Stadium - Pittsburgh, PA - United States": ACRISURE_STADIUM,
    "Astrodome - Houston, TX - United States": NRG_STADIUM,
    "Mile High Stadium -  - ": EMPOWER_FIELD,
    "Football Park - Australia": AAMI_STADIUM,
    "Docklands - Australia": MARVEL_STADIUM,
    "Manuka Oval - Australia": MANUKA_OVAL,
    "Stadium Australia - Australia": ENGIE_STADIUM,
    "York Park - Australia": UTAS_STADIUM,
    "Marrara Oval - Australia": TIO_STADIUM,
    "Adelaide Oval - Australia": ADELAIDE_OVAL,
    "Sydney Showground - Australia": ENGIE_STADIUM,
    "Bellerive Oval - Australia": BLUNDSTONE_ARENA,
    "Cazaly's Stadium - Australia": CAZALYS_STADIUM,
    "Wellington - Australia": WESTPAC_STADIUM,
    "Traeger Park - Australia": TRAEGER_PARK,
    "Eureka Stadium - Australia": MARS_STADIUM,
    "Perth Stadium - Australia": OPTUS_STADIUM,
    "Jiangwan Stadium - Australia": JIANGWAN_STADIUM,
    "Soldier Field - Chicago, Illinois - United States": SOLDIER_FIELD,
    "Arrowhead Stadium - Kansas City, Missouri - United States": ARROWHEAD_STADIUM,
    "Yale Bowl - New Haven, Connecticut, USA - United States": YALE_BOWL,
    "Rice Stadium - Houston, Texas, U.S. - United States": RICE_STADIUM,
    "Giants Stadium - New York - United States": METLIFE_STADIUM,
    "Rose Bowl - Hampshire - England": ROSE_BOWL,
    "Riverfront Stadium - Cincinnati, OH - United States": PAYCOR_STADIUM,
    "Kingdome - Seattle, WA - United States": LUMEN_FIELD,
    "Milwaukee County Stadium - Milwaukee, WI - United States": MILWAUKEE_COUNTY_STADIUM,
    "Candlestick Park - San Francisco, CA - United States": CANDLESTICK_PARK,
    "Cleveland Municipal Stadium - Cleveland, OH - United States": CLEVELAND_BROWNS_STADIUM,
    "Stanford Stadium - Stanford, California, USA - United States": STANFORD_STADIUM,
    "Sun Devil Stadium - Tempe, Arizona, USA - United States": MOUNTAIN_AMERICA_STADIUM,
    "Liberty Bowl Memorial Stadium - Memphis, Tennessee, USA - United States": LIBERTY_BOWL_MEMORIAL_STADIUM,
    "Qualcomm Stadium - San Diego, California - United States": SDCCU_STADIUM,
    "Raymond James Stadium - Tampa Bay, Florida, USA - United States": RAYMOND_JAMES_STADIUM,
    "Cleveland Browns Stadium - Cleveland, Ohio - United States": CLEVELAND_BROWNS_STADIUM,
    "Citi Field - Flushing, New York - United States": SHEA_STADIUM,
    "Bruce Stadium - Australia": SportsballGeocodeTuple(
        city="Bruce",
        state="ACT",
        postal="2617",
        lat=-35.249994,
        lng=149.1001351,
        housenumber="",
        country="Australia",
    ),
    "Blacktown - Australia": BLACKTOWN_PARK,
    "Gillette Stadium - Foxborough, Massachusetts - United States": GILETTE_STADIUM,
    "Riverway Stadium - Australia": RIVERWAY_STADIUM,
    "Norwood Oval - Australia": NORWOOD_OVAL,
    "Summit Sports Park - Australia": ADELAIDE_HILLS,
    "Mile High": EMPOWER_FIELD,
    "Nissan Stadium - Nashville, Tennessee, USA - United States": NISSAN_STADIUM,
    "SoFi Stadium - Inglewood, CA - United States": SOFI_STADIUM,
    "Highmark Stadium - Orchard Park, New York - United States": HIGHMARK_STADIUM,
    "Mercedes-Benz Stadium - Atlanta, Georgia - United States": MERCEDES_BANZ_STADIUM,
    "Lucas Oil Stadium - Indianapolis, Indiana, USA - United States": LUCAS_OIL_STADIUM,
    "U.S. Bank Stadium - Minneapolis, Minnesota, USA - United States": US_BANK_STADIUM,
    "Caesars Superdome - New Orleans, Louisiana, United States - United States": CAESARS_SUPERDOME,
    "Acrisure Stadium - Pittsburgh, Pennsylvania, USA - United States": ACRISURE_STADIUM,
    "FedExField - Landover, Maryland, USA - United States": FEDEX_FIELD,
    "M&T Bank Stadium - Baltimore, Maryland - United States": MTT_BANK_STADIUM,
    "Empower Field at Mile High - Denver, Colorado, USA - United States": EMPOWER_FIELD,
    "Lumen Field - Seattle, WA, USA - United States": LUMEN_FIELD,
    "MetLife Stadium - East Rutherford, New Jersey - United States": METLIFE_STADIUM,
    "Lincoln Financial Field - Philadelphia, Pennsylvania - United States": LINCOLN_FINANCIAL_FIELD,
    "Paycor Stadium - Cincinnati, Ohio - United States": PAYCOR_STADIUM,
    "Ford Field - Detroit, Michigan - United States": FORD_FIELD,
    "EverBank Stadium - Jacksonville, Florida - United States": EVERBANK_STADIUM,
    "NRG Stadium - Houston, Texas, USA - United States": NRG_STADIUM,
    "State Farm Stadium - Glendale, Arizona - United States": STATE_FARM_STADIUM,
    "AT&T Stadium - Arlington, Texas, USA - United States": ATT_STADIUM,
    "Bank of America Stadium - Charlotte, NC, United States - United States": BANK_OF_AMERICA_STADIUM,
    "Hard Rock Stadium - Coral Gables, Florida, USA - United States": HARD_ROCK_STADIUM,
    "GEHA Field at Arrowhead Stadium - Kansas City, Missouri, United States - United States": ARROWHEAD_STADIUM,
    "Wembley Stadium - Wembley, London - International": WEMBLEY_STADIUM,
    "Tottenham Hotspur Stadium - Bill Nicholson Way, Tottenham, London - England": TOTTENHAM_HOTSPURS_STADIUM,
    "Deutsche Bank Park - Frankfurt, Germany - Germany": DEUTSCHE_BANK_PARK,
    "Arlington Stadium - Arlington, TX - United States": ATT_STADIUM,
    "Allegiant Stadium - Paradise, Nevada, USA - United States": ALLEGIANT_STADIUM,
    "Neo Química Arena - São Paulo, Brazil - Brazil": NEO_QUIMICA_ARENA,
    "Allianz Arena - Munich, Germany - Germany": ALLIANZ_ARENA,
    "Levi's Stadium - Santa Clara, California, USA - United States": LEVI_STADIUM,
    "MCG": MCG,
    "SCG": SCG,
    "ENGIE Stadium": ENGIE_STADIUM,
    "Adelaide Oval": ADELAIDE_OVAL,
    "Gabba": GABBA,
    "Optus Stadium": OPTUS_STADIUM,
    "Marvel Stadium": MARVEL_STADIUM,
    "Mars Stadium": MARS_STADIUM,
    "GMHBA Stadium": GMHBA_STADIUM,
    "UTAS Stadium": UTAS_STADIUM,
    "People First Stadium": PEOPLE_FIRST_STADIUM,
    "Blundstone Arena": BLUNDSTONE_ARENA,
    "Manuka Oval": MANUKA_OVAL,
    "TIO Stadium": TIO_STADIUM,
    "Norwood Oval": NORWOOD_OVAL,
    "Adelaide Hills": ADELAIDE_HILLS,
    "Traeger Park": TRAEGER_PARK,
    "Cazaly’s Stadium": CAZALYS_STADIUM,
    "Marvl": MARVEL_STADIUM,
    "Accor Stadium": ENGIE_STADIUM,
    "Riverway Stadium": RIVERWAY_STADIUM,
    "Jiangwan Sports Centre": JIANGWAN_STADIUM,
    "Domain Stadium": DOMAIN_STADIUM,
    "Westpac Stadium": WESTPAC_STADIUM,
    "AAMI Stadium": AAMI_STADIUM,
    "Blacktown Park": BLACKTOWN_PARK,
    "Husky Stadium - Seattle - WA - 98195": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="98195",
        lat=47.6503,
        lng=-122.3016,
        housenumber="3800",
        country="USA",
    ),
    "L&N Federal Credit Union Stadium - Louisville - KY - 40208": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="40208",
        lat=38.205833,
        lng=-85.758889,
        housenumber="2800",
        country="USA",
    ),
    "Bobcat Stadium (TX) - San Marcos - TX - 78666": SportsballGeocodeTuple(
        city="San Marcos",
        state="TX",
        postal="78666",
        lat=29.891111,
        lng=-97.925556,
        housenumber="1100",
        country="USA",
    ),
    "Rice-Eccles Stadium - Salt Lake City - UT - 84112": SportsballGeocodeTuple(
        city="Salt Lake City",
        state="UT",
        postal="84112",
        lat=40.759975,
        lng=-111.848853,
        housenumber="451",
        country="USA",
    ),
    "Boone Pickens Stadium - Stillwater - OK - 74075": SportsballGeocodeTuple(
        city="Stillwater",
        state="OK",
        postal="74075",
        lat=36.125833,
        lng=-97.066389,
        housenumber="700",
        country="USA",
    ),
    "Cajun Field - Lafayette - LA - 70506": SportsballGeocodeTuple(
        city="Lafayette",
        state="LA",
        postal="70506",
        lat=30.215833,
        lng=-92.041944,
        housenumber="201",
        country="USA",
    ),
    "Ben Hill Griffin Stadium - Gainesville - FL - 32611": SportsballGeocodeTuple(
        city="Gainesville",
        state="FL",
        postal="32611",
        lat=29.6500337,
        lng=-82.3488407,
        housenumber="157",
        country="USA",
    ),
    "Protective Stadium - Birmingham - AL - 35203": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="35203",
        lat=33.5278,
        lng=-86.8092,
        housenumber="",
        country="USA",
    ),
    "Warren McGuirk Alumni Stadium - Amherst - MA - 01003": SportsballGeocodeTuple(
        city="Amherst",
        state="MA",
        postal="01003",
        lat=42.377306,
        lng=-72.536019,
        housenumber="300",
        country="USA",
    ),
    "Doyt L. Perry Stadium - Bowling Green - OH - 43403": SportsballGeocodeTuple(
        city="Bowling Green",
        state="OH",
        postal="43403",
        lat=41.378056,
        lng=-83.6225,
        housenumber="",
        country="USA",
    ),
    "Allegacy Federal Credit Union Stadium - Winston-Salem - NC - 27105": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="27105",
        lat=36.130556,
        lng=-80.254722,
        housenumber="411",
        country="USA",
    ),
    "McLane Stadium - Waco - TX - 76704": SportsballGeocodeTuple(
        city="Waco",
        state="TX",
        postal="76704",
        lat=31.5582,
        lng=-97.1157,
        housenumber="1001",
        country="USA",
    ),
    "Autzen Stadium - Eugene - OR - 97401": SportsballGeocodeTuple(
        city="Eugene",
        state="OR",
        postal="97401",
        lat=44.058333,
        lng=-123.068611,
        housenumber="2727",
        country="USA",
    ),
    "Lanny and Sharon Martin Stadium - Evanston - IL - 60208": LANNY_AND_SHARON_MARTIN_STADIUM,
    "Kinnick Stadium - Iowa City - IA - 52240": SportsballGeocodeTuple(
        city="Iowa City",
        state="IA",
        postal="52240",
        lat=41.658611,
        lng=-91.551111,
        housenumber="886",
        country="USA",
    ),
    "Carter-Finley Stadium - Raleigh - NC - 27607": SportsballGeocodeTuple(
        city="Raleigh",
        state="NC",
        postal="27607",
        lat=35.800833,
        lng=-78.719444,
        housenumber="4600",
        country="USA",
    ),
    "Bobby Dodd Stadium - Atlanta - GA - 30332": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30332",
        lat=33.7725,
        lng=-84.392778,
        housenumber="155",
        country="USA",
    ),
    "Aviva Stadium - Dublin": SportsballGeocodeTuple(
        city="Dublin",
        state="",
        postal="D04K5F9",
        lat=53.335278,
        lng=-6.228333,
        housenumber="62",
        country="Ireland",
    ),
    "Doak Campbell Stadium - Tallahassee - FL - 32304": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="32304",
        lat=30.438056,
        lng=-84.304444,
        housenumber="403",
        country="USA",
    ),
    "Ross-Ade Stadium - West Lafayette - IN - 47906": SportsballGeocodeTuple(
        city="West Lafayette",
        state="IN",
        postal="47906",
        lat=40.434444,
        lng=-86.918333,
        housenumber="850",
        country="USA",
    ),
    "Clarence T.C. Ching Athletics Complex - Honolulu - HI - 96822": SportsballGeocodeTuple(
        city="Honolulu",
        state="HI",
        postal="96822",
        lat=21.294,
        lng=-157.818,
        housenumber="",
        country="USA",
    ),
    "Mackay Stadium - Reno - NV - 89557": SportsballGeocodeTuple(
        city="Reno",
        state="NV",
        postal="89557",
        lat=39.546944,
        lng=-119.8175,
        housenumber="1664",
        country="USA",
    ),
    "Veterans Memorial Stadium (AL) - Troy - AL - 36082": SportsballGeocodeTuple(
        city="Troy",
        state="AL",
        postal="36082",
        lat=31.799444,
        lng=-85.951944,
        housenumber="338",
        country="USA",
    ),
    "Memorial Stadium - Columbia - MO - 65203": SportsballGeocodeTuple(
        city="Columbia",
        state="MO",
        postal="65203",
        lat=38.935833,
        lng=-92.333056,
        housenumber="600",
        country="USA",
    ),
    "Glass Bowl - Toledo - OH - 43606": SportsballGeocodeTuple(
        city="Toledo",
        state="OH",
        postal="43606",
        lat=41.656944,
        lng=-83.613611,
        housenumber="3044",
        country="USA",
    ),
    "Milan Puskar Stadium - Morgantown - WV - 26505": SportsballGeocodeTuple(
        city="Morgantown",
        state="WV",
        postal="26505",
        lat=39.650278,
        lng=-79.954722,
        housenumber="900",
        country="USA",
    ),
    "Ohio Stadium - Columbus - OH - 43210": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="43210",
        lat=40.001667,
        lng=-83.019722,
        housenumber="411",
        country="USA",
    ),
    "Memorial Stadium (Bloomington, IN) - Bloomington - IN - 47408": SportsballGeocodeTuple(
        city="Bloomington",
        state="IN",
        postal="47408",
        lat=39.180833,
        lng=-86.525556,
        housenumber="701",
        country="USA",
    ),
    "Jordan-Hare Stadium - Auburn - AL - 36849": SportsballGeocodeTuple(
        city="Auburn",
        state="AL",
        postal="36849",
        lat=32.602222,
        lng=-85.489167,
        housenumber="251",
        country="USA",
    ),
    "Camp Randall Stadium - Madison - WI - 53711": SportsballGeocodeTuple(
        city="Madison",
        state="WI",
        postal="53711",
        lat=43.07,
        lng=-89.412778,
        housenumber="",
        country="USA",
    ),
    "War Memorial Stadium (AR) - Little Rock - AR - 72205": SportsballGeocodeTuple(
        city="Little Rock",
        state="AR",
        postal="72205",
        lat=34.749861,
        lng=-92.33,
        housenumber="1",
        country="USA",
    ),
    "AmFirst Stadium - Jacksonville - AL - 36265": SportsballGeocodeTuple(
        city="Jacksonville",
        state="AL",
        postal="36265",
        lat=33.820278,
        lng=-85.766389,
        housenumber="700",
        country="USA",
    ),
    "Jones AT&T Stadium - Lubbock - TX - 79407": SportsballGeocodeTuple(
        city="Lubbock",
        state="TX",
        postal="79407",
        lat=33.591111,
        lng=-101.872778,
        housenumber="2526",
        country="USA",
    ),
    "Bryant-Denny Stadium - Tuscaloosa - AL - 35401": SportsballGeocodeTuple(
        city="Tuscaloosa",
        state="AL",
        postal="35401",
        lat=33.208333,
        lng=-87.550278,
        housenumber="920",
        country="USA",
    ),
    "Dowdy-Ficklen Stadium - Greenville - NC - 37604": SportsballGeocodeTuple(
        city="Greenville",
        state="NC",
        postal="37604",
        lat=35.596389,
        lng=-77.365278,
        housenumber="100",
        country="USA",
    ),
    "SHI Stadium - Piscataway - NJ - 08854": SportsballGeocodeTuple(
        city="Piscataway",
        state="NJ",
        postal="08854",
        lat=40.513611,
        lng=-74.465278,
        housenumber="1",
        country="USA",
    ),
    "Folsom Field - Boulder - CO - 80305": SportsballGeocodeTuple(
        city="Boulder",
        state="CO",
        postal="80305",
        lat=40.009,
        lng=-105.267,
        housenumber="2400",
        country="USA",
    ),
    "Kroger Field - Lexington - KY - 40506": SportsballGeocodeTuple(
        city="Lexington",
        state="KY",
        postal="40506",
        lat=38.022778,
        lng=-84.505278,
        housenumber="1540",
        country="USA",
    ),
    "Williams Stadium (VA) - Lynchburg - VA - 24502": SportsballGeocodeTuple(
        city="Lynchburg",
        state="VA",
        postal="24502",
        lat=37.354,
        lng=-79.175,
        housenumber="1972",
        country="USA",
    ),
    "JMA Wireless Dome - Syracuse - NY - 13244": SportsballGeocodeTuple(
        city="Syracuse",
        state="NY",
        postal="13244",
        lat=43.036111,
        lng=-76.136389,
        housenumber="900",
        country="USA",
    ),
    "Davis Wade Stadium - Starkville - MS - 39762": SportsballGeocodeTuple(
        city="Starkville",
        state="MS",
        postal="39762",
        lat=33.456389,
        lng=-88.793611,
        housenumber="90",
        country="USA",
    ),
    "FBC Mortgage Stadium - Orlando - FL - 32816": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="32816",
        lat=28.6091,
        lng=-81.1924,
        housenumber="4465",
        country="USA",
    ),
    "SECU Stadium - College Park - MD - 20742": SportsballGeocodeTuple(
        city="College Park",
        state="MD",
        postal="20742",
        lat=38.990278,
        lng=-76.947222,
        housenumber="90",
        country="USA",
    ),
    "Michigan Stadium - Ann Arbor - MI - 48104": SportsballGeocodeTuple(
        city="Ann Arbor",
        state="MI",
        postal="48104",
        lat=42.2661,
        lng=-83.7508,
        housenumber="1201",
        country="USA",
    ),
    "Memorial Stadium (Champaign, IL) - Champaign - IL - 61820": SportsballGeocodeTuple(
        city="Champaign",
        state="IL",
        postal="61820",
        lat=40.099167,
        lng=-88.235833,
        housenumber="1402",
        country="USA",
    ),
    "Simmons Bank Liberty Stadium - Memphis - TN - 38104": SportsballGeocodeTuple(
        city="Memphis",
        state="TN",
        postal="38104",
        lat=35.121,
        lng=-89.9774,
        housenumber="335",
        country="USA",
    ),
    "Huskie Stadium - Dekalb - IL - 60115": SportsballGeocodeTuple(
        city="Dekalb",
        state="IL",
        postal="60115",
        lat=41.934,
        lng=-88.778,
        housenumber="1245",
        country="USA",
    ),
    "FirstBank Stadium - Nashville - TN - 37212": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37212",
        lat=36.144167,
        lng=-86.808889,
        housenumber="",
        country="USA",
    ),
    'Johnny "Red" Floyd Stadium - Murfreesboro - TN - 37130': SportsballGeocodeTuple(
        city="Murfreesboro",
        state="TN",
        postal="37130",
        lat=35.850513,
        lng=-86.368223,
        housenumber="1327",
        country="USA",
    ),
    "Kelly/Shorts Stadium - Mount Pleasant - MI - 48858": SportsballGeocodeTuple(
        city="Mount Pleasant",
        state="MI",
        postal="48858",
        lat=43.5775,
        lng=-84.770833,
        housenumber="2300",
        country="USA",
    ),
    "Kyle Field - College Station - TX - 77840": SportsballGeocodeTuple(
        city="College Station",
        state="TX",
        postal="77840",
        lat=30.6099,
        lng=-96.3405,
        housenumber="756",
        country="USA",
    ),
    "Allen E. Paulson Stadium - Statesboro - GA - 30458": SportsballGeocodeTuple(
        city="Statesboro",
        state="GA",
        postal="30458",
        lat=32.412161,
        lng=-81.783135,
        housenumber="207",
        country="USA",
    ),
    "Stanford Stadium - Stanford - CA - 94305": SportsballGeocodeTuple(
        city="Stanford",
        state="CA",
        postal="94305",
        lat=37.434444,
        lng=-122.161111,
        housenumber="625",
        country="USA",
    ),
    "Wallace Wade Stadium - Durham - NC - 27708": SportsballGeocodeTuple(
        city="Durham",
        state="NC",
        postal="27708",
        lat=35.995278,
        lng=-78.941667,
        housenumber="",
        country="USA",
    ),
    "Vaught-Hemingway Stadium - Oxford - MS - 38655": SportsballGeocodeTuple(
        city="Oxford",
        state="MS",
        postal="38655",
        lat=34.361944,
        lng=-89.534167,
        housenumber="6",
        country="USA",
    ),
    "TDECU Stadium - Houston - TX - 77204": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77204",
        lat=29.721944,
        lng=-95.349167,
        housenumber="3874",
        country="USA",
    ),
    "Joan C. Edwards Stadium - Huntington - WV - 25703": SportsballGeocodeTuple(
        city="Huntington",
        state="WV",
        postal="25703",
        lat=38.425,
        lng=-82.420833,
        housenumber="2001",
        country="USA",
    ),
    "Hancock Whitney Stadium - Mobile - AL - 36688": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="36688",
        lat=30.696904,
        lng=-88.192013,
        housenumber="",
        country="USA",
    ),
    "Maverik Stadium - Logan - UT - 84341": SportsballGeocodeTuple(
        city="Logan",
        state="UT",
        postal="84341",
        lat=41.751667,
        lng=-111.811667,
        housenumber="1000",
        country="USA",
    ),
    "Williams-Brice Stadium - Columbia - SC - 29201": SportsballGeocodeTuple(
        city="Columbia",
        state="SC",
        postal="29201",
        lat=33.973056,
        lng=-81.019167,
        housenumber="1174",
        country="USA",
    ),
    "Spartan Stadium - East Lansing - MI - 48824": SportsballGeocodeTuple(
        city="East Lansing",
        state="MI",
        postal="48824",
        lat=42.728056,
        lng=-84.484722,
        housenumber="1",
        country="USA",
    ),
    "Alamodome - San Antonio - TX - 78203": ALAMODOME,
    "Jack Trice Stadium - Ames - IA - 50011": SportsballGeocodeTuple(
        city="Ames",
        state="IA",
        postal="50011",
        lat=42.014167,
        lng=-93.635833,
        housenumber="1798",
        country="USA",
    ),
    "Arizona Stadium - Tucson - AZ - 85719": SportsballGeocodeTuple(
        city="Tucson",
        state="AZ",
        postal="85719",
        lat=32.229,
        lng=-110.949,
        housenumber="545",
        country="USA",
    ),
    "California Memorial Stadium - Berkeley - CA - 94720": SportsballGeocodeTuple(
        city="Berkeley",
        state="CA",
        postal="94720",
        lat=37.871111,
        lng=-122.250833,
        housenumber="210",
        country="USA",
    ),
    "Memorial Stadium (Norman, OK) - Norman - OK - 73019": SportsballGeocodeTuple(
        city="Norman",
        state="OK",
        postal="73019",
        lat=35.205833,
        lng=-97.4425,
        housenumber="1185",
        country="USA",
    ),
    "Neyland Stadium - Knoxville - TN - 37996": SportsballGeocodeTuple(
        city="Knoxville",
        state="TN",
        postal="37996",
        lat=35.955,
        lng=-83.925,
        housenumber="1235",
        country="USA",
    ),
    "Bill Snyder Family Stadium - Manhattan - KS - 66502": SportsballGeocodeTuple(
        city="Manhattan",
        state="KS",
        postal="66502",
        lat=39.201944,
        lng=-96.593889,
        housenumber="1800",
        country="USA",
    ),
    "Jerry Richardson Stadium - Charlotte - NC - 28223": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="28223",
        lat=35.310556,
        lng=-80.740278,
        housenumber="",
        country="USA",
    ),
    "UB Stadium - Buffalo - NY - 14228": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="14228",
        lat=42.999167,
        lng=-78.7775,
        housenumber="",
        country="USA",
    ),
    "Michie Stadium - West Point - NY - 10996": SportsballGeocodeTuple(
        city="West Point",
        state="NY",
        postal="10996",
        lat=41.3875,
        lng=-73.964167,
        housenumber="700",
        country="USA",
    ),
    "DKR-Texas Memorial Stadium - Austin - TX - 78712": SportsballGeocodeTuple(
        city="Austin",
        state="TX",
        postal="78712",
        lat=30.28367,
        lng=-97.73256,
        housenumber="405",
        country="USA",
    ),
    "Nippert Stadium - Cincinnati - OH - 45221": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="45221",
        lat=39.1312,
        lng=-84.5162,
        housenumber="2700",
        country="USA",
    ),
    "Rice Stadium - Houston - TX - 77005": RICE_STADIUM,
    "Scott Stadium - Charlottesville - VA - 22903": SportsballGeocodeTuple(
        city="Charlottesville",
        state="VA",
        postal="22903",
        lat=38.031111,
        lng=-78.513611,
        housenumber="1815",
        country="USA",
    ),
    "Memorial Stadium (Lincoln, NE) - Lincoln - NE - 68508": SportsballGeocodeTuple(
        city="Lincoln",
        state="NE",
        postal="68508",
        lat=40.8206,
        lng=-96.706,
        housenumber="600",
        country="USA",
    ),
    "Centennial Bank Stadium - Jonesboro - AR - 72401": SportsballGeocodeTuple(
        city="Jonesboro",
        state="AR",
        postal="72401",
        lat=35.848889,
        lng=-90.667222,
        housenumber="2180",
        country="USA",
    ),
    "Navy-Marine Corps Memorial Stadium - Annapolis - MD - 21401": SportsballGeocodeTuple(
        city="Annapolis",
        state="MD",
        postal="21401",
        lat=38.985,
        lng=-76.507,
        housenumber="550",
        country="USA",
    ),
    "Malone Stadium - Monroe - LA - 71203": SportsballGeocodeTuple(
        city="Monroe",
        state="LA",
        postal="71203",
        lat=32.530833,
        lng=-92.065833,
        housenumber="514",
        country="USA",
    ),
    "Gerald J. Ford Stadium - Dallas - TX - 75205": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="75205",
        lat=32.836644,
        lng=-96.783994,
        housenumber="5801",
        country="USA",
    ),
    "CEFCU Stadium - San Jose - CA - 95112": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="95112",
        lat=37.31972,
        lng=-121.868333,
        housenumber="1257",
        country="USA",
    ),
    "University Stadium (NM) - Albuquerque - NM - 87106": SportsballGeocodeTuple(
        city="Albuquerque",
        state="NM",
        postal="87106",
        lat=35.066944,
        lng=-106.628333,
        housenumber="1111",
        country="USA",
    ),
    "Snapdragon Stadium - San Diego - CA - 92108": SDCCU_STADIUM,
    "LaVell Edwards Stadium - Provo - UT - 84604": SportsballGeocodeTuple(
        city="Provo",
        state="UT",
        postal="84604",
        lat=40.258,
        lng=-111.655,
        housenumber="1700",
        country="USA",
    ),
    "Joe Aillet Stadium - Ruston - LA - 71270": SportsballGeocodeTuple(
        city="Ruston",
        state="LA",
        postal="71270",
        lat=32.532021,
        lng=-92.655899,
        housenumber="1450",
        country="USA",
    ),
    "Chapman Stadium - Tulsa - OK - 74104": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="74104",
        lat=36.148611,
        lng=-95.943889,
        housenumber="3112",
        country="USA",
    ),
    "Falcon Stadium - USAF Academy - CO - 80840": SportsballGeocodeTuple(
        city="",
        state="CO",
        postal="80840",
        lat=38.997,
        lng=-104.843,
        housenumber="4900",
        country="USA",
    ),
    "Kidd Brewer Stadium - Boone - NC - 28607": SportsballGeocodeTuple(
        city="Boone",
        state="NC",
        postal="28607",
        lat=36.211667,
        lng=-81.685556,
        housenumber="270",
        country="USA",
    ),
    "Aggie Memorial Stadium - Las Cruces - NM - 88003": SportsballGeocodeTuple(
        city="Las Cruces",
        state="NM",
        postal="88003",
        lat=32.27949,
        lng=-106.744288,
        housenumber="",
        country="USA",
    ),
    "Fifth Third Stadium - Kennesaw - GA - 30144": SportsballGeocodeTuple(
        city="Kennesaw",
        state="GA",
        postal="30144",
        lat=34.028967,
        lng=-84.567626,
        housenumber="3200",
        country="USA",
    ),
    "Beaver Stadium - University Park - PA - 16802": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="16802",
        lat=40.8121,
        lng=-77.856,
        housenumber="1",
        country="USA",
    ),
    "Pratt & Whitney Stadium - East Hartford - CT - 06118": SportsballGeocodeTuple(
        city="East Hartford",
        state="CT",
        postal="06118",
        lat=41.759722,
        lng=-72.618889,
        housenumber="615",
        country="USA",
    ),
    "Sanford Stadium - Athens - GA - 30602": SportsballGeocodeTuple(
        city="Athens",
        state="GA",
        postal="30602",
        lat=33.949803,
        lng=-83.373364,
        housenumber="",
        country="USA",
    ),
    "Gesa Field - Pullman - WA - 99164": SportsballGeocodeTuple(
        city="Pullman",
        state="WA",
        postal="99164",
        lat=46.732,
        lng=-117.16,
        housenumber="720",
        country="USA",
    ),
    "Houchens Industries-L.T. Smith Stadium - Bowling Green - KY - 42101": SportsballGeocodeTuple(
        city="Bowling Green",
        state="KY",
        postal="42101",
        lat=36.984722,
        lng=-86.459444,
        housenumber="",
        country="USA",
    ),
    "Center Parc Stadium - Atlanta - GA - 30315": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30315",
        lat=33.735278,
        lng=-84.389444,
        housenumber="755",
        country="USA",
    ),
    "S.B. Ballard Stadium - Norfolk - VA - 23508": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23508",
        lat=36.8889,
        lng=-76.304878,
        housenumber="5115",
        country="USA",
    ),
    "M. M. Roberts Stadium - Hattiesburg - MS - 39406": SportsballGeocodeTuple(
        city="Hattiesburg",
        state="MS",
        postal="39406",
        lat=31.328889,
        lng=-89.331389,
        housenumber="118",
        country="USA",
    ),
    "Tiger Stadium (LA) - Baton Rouge - LA - 70803": SportsballGeocodeTuple(
        city="Baton Rouge",
        state="LA",
        postal="70803",
        lat=30.412222,
        lng=-91.183889,
        housenumber="",
        country="USA",
    ),
    "Valley Children's Stadium - Fresno - CA - 93710": SportsballGeocodeTuple(
        city="Fresno",
        state="CA",
        postal="93710",
        lat=36.814,
        lng=-119.758,
        housenumber="1620",
        country="USA",
    ),
    "Peden Stadium - Athens - OH - 45701": SportsballGeocodeTuple(
        city="Athens",
        state="OH",
        postal="45701",
        lat=39.321111,
        lng=-82.102778,
        housenumber="200",
        country="USA",
    ),
    "Notre Dame Stadium - Notre Dame - IN - 46556": SportsballGeocodeTuple(
        city="Notre Dame",
        state="IN",
        postal="46556",
        lat=41.69833,
        lng=-86.23389,
        housenumber="2010",
        country="USA",
    ),
    "Lane Stadium - Blacksburg - VA - 24060": SportsballGeocodeTuple(
        city="Blacksburg",
        state="VA",
        postal="24060",
        lat=37.22,
        lng=-80.418056,
        housenumber="285",
        country="USA",
    ),
    "Pitbull Stadium - Miami - FL - 33199": PITBULL_STADIUM,
    "Amon G. Carter Stadium - Fort Worth - TX - 76129": SportsballGeocodeTuple(
        city="Fort Worth",
        state="TX",
        postal="76129",
        lat=32.709722,
        lng=-97.368056,
        housenumber="2850",
        country="USA",
    ),
    "Memorial Stadium (Clemson, SC) - Clemson - SC - 29634": SportsballGeocodeTuple(
        city="Clemson",
        state="SC",
        postal="29634",
        lat=34.678611,
        lng=-82.843056,
        housenumber="",
        country="USA",
    ),
    "Dix Stadium - Kent - OH - 44242": SportsballGeocodeTuple(
        city="Kent",
        state="OH",
        postal="44242",
        lat=41.139167,
        lng=-81.313333,
        housenumber="2227",
        country="USA",
    ),
    "DATCU Stadium - Denton - TX - 76205": SportsballGeocodeTuple(
        city="Denton",
        state="TX",
        postal="76205",
        lat=33.203611,
        lng=-97.159444,
        housenumber="1251",
        country="USA",
    ),
    "FAU Stadium - Boca Raton - FL - 33431": SportsballGeocodeTuple(
        city="Boca Raton",
        state="FL",
        postal="33431",
        lat=26.375278,
        lng=-80.100278,
        housenumber="777",
        country="USA",
    ),
    "Kenan Stadium - Chapel Hill - NC - 27514": SportsballGeocodeTuple(
        city="Chapel Hill",
        state="NC",
        postal="27514",
        lat=35.906944,
        lng=-79.047778,
        housenumber="78",
        country="USA",
    ),
    "Brooks Stadium (SC) - Conway - SC - 29526": SportsballGeocodeTuple(
        city="Conway",
        state="SC",
        postal="29526",
        lat=33.7929,
        lng=-79.0175,
        housenumber="540",
        country="USA",
    ),
    "Canvas Stadium - Fort Collins - CO - 80521": SportsballGeocodeTuple(
        city="Fort Collins",
        state="CO",
        postal="80521",
        lat=40.5698965,
        lng=-105.0910097,
        housenumber="751",
        country="USA",
    ),
    "Yulman Stadium - New Orleans - LA - 70118": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="70118",
        lat=29.94482,
        lng=-90.116816,
        housenumber="",
        country="USA",
    ),
    "Bridgeforth Stadium - Harrisonburg - VA - 22807": SportsballGeocodeTuple(
        city="Harrisonburg",
        state="VA",
        postal="22807",
        lat=38.435278,
        lng=-78.873056,
        housenumber="",
        country="USA",
    ),
    "War Memorial Stadium - Laramie - WY - 82070": SportsballGeocodeTuple(
        city="Laramie",
        state="WY",
        postal="82070",
        lat=41.3117075,
        lng=-105.5708596,
        housenumber="",
        country="USA",
    ),
    "Sun Bowl - El Paso - TX - 79902": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="79902",
        lat=31.773,
        lng=-106.508,
        housenumber="2701",
        country="USA",
    ),
    "Scheumann Stadium - Muncie - IN - 47304": SportsballGeocodeTuple(
        city="Muncie",
        state="IN",
        postal="47304",
        lat=40.216111,
        lng=-85.416667,
        housenumber="",
        country="USA",
    ),
    "Razorback Stadium - Fayetteville - AR - 72701": SportsballGeocodeTuple(
        city="Fayetteville",
        state="AR",
        postal="72701",
        lat=36.068056,
        lng=-94.178889,
        housenumber="350",
        country="USA",
    ),
    "Reser Stadium - Corvallis - OR - 97331": SportsballGeocodeTuple(
        city="Corvallis",
        state="OR",
        postal="97331",
        lat=44.5595424,
        lng=-123.2839683,
        housenumber="2600",
        country="USA",
    ),
    "Yager Stadium - Oxford - OH - 45056": SportsballGeocodeTuple(
        city="Oxford",
        state="OH",
        postal="45056",
        lat=39.5195227,
        lng=-84.7355128,
        housenumber="",
        country="USA",
    ),
    "Rose Bowl - Pasadena - CA - 91103": ROSE_BOWL,
    "Waldo Stadium - Kalamazoo - MI - 49008": SportsballGeocodeTuple(
        city="Kalamazoo",
        state="MI",
        postal="49008",
        lat=42.285833,
        lng=-85.601111,
        housenumber="1903",
        country="USA",
    ),
    "InfoCision Stadium - Akron - OH - 44304": SportsballGeocodeTuple(
        city="Akron",
        state="OH",
        postal="44304",
        lat=41.072347,
        lng=-81.508019,
        housenumber="",
        country="USA",
    ),
    "Rynearson Stadium - Ypsilanti - MI - 48197": SportsballGeocodeTuple(
        city="Ypsilanti",
        state="MI",
        postal="48197",
        lat=42.2558889,
        lng=-83.6499574,
        housenumber="799",
        country="USA",
    ),
    "Children's Mercy Park - Kansas City - KS - 66111": SportsballGeocodeTuple(
        city="Kansas City",
        state="KS",
        postal="66111",
        lat=39.12174,
        lng=-94.82318,
        housenumber="1",
        country="USA",
    ),
    "Elliott T. Bowers Stadium - Huntsville - TX - 77340": SportsballGeocodeTuple(
        city="Huntsville",
        state="TX",
        postal="77340",
        lat=30.713889,
        lng=-95.541667,
        housenumber="620",
        country="USA",
    ),
    "Alumni Stadium (Chestnut Hill, MA) - Chestnut Hill - MA - 02467": SportsballGeocodeTuple(
        city="Chestnut Hill",
        state="MA",
        postal="02467",
        lat=42.335,
        lng=-71.166389,
        housenumber="",
        country="USA",
    ),
    "Albertsons Stadium - Boise - ID - 83706": SportsballGeocodeTuple(
        city="Boise",
        state="ID",
        postal="83706",
        lat=43.603,
        lng=-116.196,
        housenumber="1400",
        country="USA",
    ),
    "Cotton Bowl - Dallas - TX - 75215": COTTON_BOWL,
    "Wrigley Field - Chicago - IL - 60613": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60613",
        lat=41.948056,
        lng=-87.655556,
        housenumber="1060",
        country="USA",
    ),
    "Yankee Stadium - Bronx - NY - 10451": SportsballGeocodeTuple(
        city="Bronx",
        state="NY",
        postal="10451",
        lat=40.829167,
        lng=-73.926389,
        housenumber="1",
        country="USA",
    ),
    "Cramton Bowl - Montgomery - AL - 36107": SportsballGeocodeTuple(
        city="Montgomery",
        state="AL",
        postal="36107",
        lat=32.37949,
        lng=-86.293002,
        housenumber="1022",
        country="USA",
    ),
    "Fenway Park - Boston - MA - 02297": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="02297",
        lat=42.34625,
        lng=-71.09775,
        housenumber="4",
        country="USA",
    ),
    "Toyota Stadium - Frisco - TX - 75033": SportsballGeocodeTuple(
        city="Frisco",
        state="TX",
        postal="75033",
        lat=33.154444,
        lng=-96.835278,
        housenumber="9200",
        country="USA",
    ),
    "Chase Field - Phoenix - AZ - 85004": SportsballGeocodeTuple(
        city="Phoenix",
        state="AZ",
        postal="85004",
        lat=33.445278,
        lng=-112.066944,
        housenumber="401",
        country="USA",
    ),
    "Thomas A. Robinson National Stadium - Nassau": SportsballGeocodeTuple(
        city="Nassau",
        state="",
        postal="",
        lat=25.054381,
        lng=-77.360217,
        housenumber="",
        country="Bahamas",
    ),
    "Independence Stadium - Shreveport - LA - 71109": SportsballGeocodeTuple(
        city="Shreveport",
        state="LA",
        postal="71109",
        lat=32.475556,
        lng=-93.791944,
        housenumber="",
        country="USA",
    ),
    "David Booth Kansas Memorial Stadium - Lawrence - KS - 66044": SportsballGeocodeTuple(
        city="Lawrence",
        state="KS",
        postal="66044",
        lat=38.963333,
        lng=-95.246389,
        housenumber="1101",
        country="USA",
    ),
    "Riccardo Silva Stadium - Miami - FL - 33199": PITBULL_STADIUM,
    "Ryan Field - Evanston - IL - 60208": LANNY_AND_SHARON_MARTIN_STADIUM,
    "Petco Park - San Diego - CA - 92101": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="92101",
        lat=32.7073,
        lng=-117.1566,
        housenumber="100",
        country="USA",
    ),
    "Providence Park - Portland - OR - 97205": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="97205",
        lat=45.521389,
        lng=-122.691667,
        housenumber="1844",
        country="USA",
    ),
    "Choctaw Stadium - Arlington - TX - 76011": SportsballGeocodeTuple(
        city="Arlington",
        state="TX",
        postal="76011",
        lat=32.751389,
        lng=-97.082778,
        housenumber="1000",
        country="USA",
    ),
    "Inter&Co Stadium - Orlando - FL - 32805": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="32805",
        lat=28.5411,
        lng=-81.3893,
        housenumber="655",
        country="USA",
    ),
    "Legion Field (AL) - Birmingham - AL - 35204": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="35204",
        lat=33.511389,
        lng=-86.842778,
        housenumber="400",
        country="USA",
    ),
    "Sam Boyd Stadium - Las Vegas - NV - 89122": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="89122",
        lat=36.086,
        lng=-115.017,
        housenumber="7000",
        country="USA",
    ),
    "HighPoint.com Stadium - Piscataway - NJ - 08854": SportsballGeocodeTuple(
        city="Piscataway",
        state="NJ",
        postal="08854",
        lat=40.513611,
        lng=-74.465278,
        housenumber="1",
        country="USA",
    ),
    "SDCCU Stadium - San Diego - CA - 92108": SDCCU_STADIUM,
    "Ladd-Peebles Stadium - Mobile - AL - 36604": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="36604",
        lat=30.673,
        lng=-88.076,
        housenumber="1621",
        country="USA",
    ),
    "loanDepot park - Miami - FL - 33125": MIAMI_ORANGE_BOWL,
    "Barker-Lane Stadium - Buies Creek - NC - 27546": SportsballGeocodeTuple(
        city="Buies Creek",
        state="NC",
        postal="27546",
        lat=35.4046,
        lng=-78.7427,
        housenumber="558",
        country="USA",
    ),
    "Kibbie Dome - Moscow - ID - 83844": SportsballGeocodeTuple(
        city="Moscow",
        state="ID",
        postal="83844",
        lat=46.726,
        lng=-117.017,
        housenumber="",
        country="USA",
    ),
    "Allianz Stadium - Sydney - NSW": SCG,
    "Tropicana Field - St. Petersburg - FL - 33705": SportsballGeocodeTuple(
        city="St. Petersburg",
        state="FL",
        postal="33705",
        lat=27.768333,
        lng=-82.653333,
        housenumber="1",
        country="USA",
    ),
    "ANZ Stadium - Sydney - NSW": ENGIE_STADIUM,
    "Hughes Stadium (CO) - Fort Collins - CO - 80526": SportsballGeocodeTuple(
        city="Fort Collins",
        state="CO",
        postal="80526",
        lat=40.562,
        lng=-105.142,
        housenumber="",
        country="USA",
    ),
    "Bristol Motor Speedway - Bristol - TN - 37620": SportsballGeocodeTuple(
        city="Bristol",
        state="TN",
        postal="37620",
        lat=36.5156,
        lng=-82.2569,
        housenumber="151",
        country="USA",
    ),
    "Rate Field - Chicago - IL - 60616": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60616",
        lat=41.83,
        lng=-87.633889,
        housenumber="333",
        country="USA",
    ),
    "Croke Park Stadium - Dublin": SportsballGeocodeTuple(
        city="Dublin",
        state="",
        postal="D03 P6K7",
        lat=53.3609,
        lng=-6.2519,
        housenumber="",
        country="Ireland",
    ),
    "Yale Bowl - New Haven - CT - 06515": YALE_BOWL,
    "Floyd Casey Stadium - Waco - TX - 76798": SportsballGeocodeTuple(
        city="Waco",
        state="TX",
        postal="76798",
        lat=31.531342,
        lng=-97.148731,
        housenumber="3088",
        country="USA",
    ),
    'William "Dick" Price Stadium - Norfolk - VA - 23504': SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23504",
        lat=36.846964,
        lng=-76.260053,
        housenumber="700",
        country="USA",
    ),
    "Superior Dome - Marquette - MI - 49855": SportsballGeocodeTuple(
        city="Marquette",
        state="MI",
        postal="49855",
        lat=46.56,
        lng=-87.393611,
        housenumber="",
        country="USA",
    ),
    "Robertson Stadium - Houston - TX - 77004": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77004",
        lat=29.721944,
        lng=-95.349167,
        housenumber="3874",
        country="USA",
    ),
    "Roy Kidd Stadium - Richmond - KY - 40475": SportsballGeocodeTuple(
        city="Richmond",
        state="KY",
        postal="40475",
        lat=37.73439,
        lng=-84.29741,
        housenumber="",
        country="USA",
    ),
    "Capital One Arena, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.898056,
        lng=-77.020833,
        housenumber="601",
        country="USA",
    ),
    "Stan Sheriff Center, Honolulu, Hawaii": SportsballGeocodeTuple(
        city="Honolulu",
        state="HI",
        postal="96822-2312",
        lat=21.294167,
        lng=-157.818889,
        housenumber="1355",
        country="USA",
    ),
    "Value City Arena, Columbus, Ohio": SportsballGeocodeTuple(
        city="Columbus",
        state="OH",
        postal="",
        lat=40.007511,
        lng=-83.025102,
        housenumber="555",
        country="USA",
    ),
    "James A. Rhodes Arena, Akron, Ohio": SportsballGeocodeTuple(
        city="Akron",
        state="OH",
        postal="44303",
        lat=41.075833,
        lng=-81.508611,
        housenumber="373",
        country="USA",
    ),
    "Resch Center, Green Bay, Wisconsin": SportsballGeocodeTuple(
        city="Green Bay",
        state="WI",
        postal="",
        lat=44.499547,
        lng=-88.055049,
        housenumber="820",
        country="USA",
    ),
    "Hagan Arena, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.995245,
        lng=-75.234806,
        housenumber="",
        country="USA",
    ),
    "Wells Fargo Center, Philadelphia, Pennsylvania": SPECTRUM,
    "UW-Milwaukee Panther Arena, Milwaukee, Wisconsin": MILWAUKEE_ARENA,
    "Pauley Pavilion, Los Angeles, California": SportsballGeocodeTuple(
        city="Los Angeles",
        state="CA",
        postal="",
        lat=34.070211,
        lng=-118.446775,
        housenumber="301",
        country="USA",
    ),
    "Save Mart Center, Fresno, California": SportsballGeocodeTuple(
        city="Fresno",
        state="CA",
        postal="",
        lat=36.809722,
        lng=-119.738611,
        housenumber="2650",
        country="USA",
    ),
    "The Pit, Albuquerque, New Mexico": THE_PIT,
    "Gill Coliseum, Corvallis, Oregon": SportsballGeocodeTuple(
        city="Corvallis",
        state="OR",
        postal="",
        lat=44.5613,
        lng=-123.2805,
        housenumber="660",
        country="USA",
    ),
    "Liacouras Center, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.979722,
        lng=-75.158611,
        housenumber="1776",
        country="USA",
    ),
    "Williams Arena, Minneapolis, Minnesota": SportsballGeocodeTuple(
        city="Minneapolis",
        state="MN",
        postal="55455",
        lat=44.976944,
        lng=-93.228333,
        housenumber="1925",
        country="USA",
    ),
    "John W. Pope Jr. Convocation Center, Buies Creek, North Carolina": SportsballGeocodeTuple(
        city="Buies Creek",
        state="NC",
        postal="27506",
        lat=35.407905,
        lng=-78.736696,
        housenumber="",
        country="USA",
    ),
    "Bob Carpenter Center, Newark, Delaware": SportsballGeocodeTuple(
        city="Newark",
        state="DE",
        postal="",
        lat=39.660556,
        lng=-75.748639,
        housenumber="631",
        country="USA",
    ),
    "FIU Arena, Miami, Florida": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="33199-2516",
        lat=25.756667,
        lng=-80.379444,
        housenumber="11200",
        country="USA",
    ),
    "UMBC Event Center, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="21250",
        lat=39.252342,
        lng=-76.707431,
        housenumber="1000",
        country="USA",
    ),
    "Ted Constant Convocation Ctr., Norfolk, Virginia": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="",
        lat=36.884169,
        lng=-76.301231,
        housenumber="4320",
        country="USA",
    ),
    "Yanitelli Center, Jersey City, New Jersey": SportsballGeocodeTuple(
        city="Jersey City",
        state="NJ",
        postal="07306",
        lat=40.727648,
        lng=-74.073173,
        housenumber="2641",
        country="USA",
    ),
    "Edmunds Center, DeLand, Florida": SportsballGeocodeTuple(
        city="DeLand",
        state="FL",
        postal="32723",
        lat=29.039584,
        lng=-81.301819,
        housenumber="143",
        country="USA",
    ),
    "Pinnacle Bank Arena, Lincoln, Nebraska": SportsballGeocodeTuple(
        city="Lincoln",
        state="NB",
        postal="",
        lat=40.817778,
        lng=-96.713333,
        housenumber="400",
        country="USA",
    ),
    "Welsh-Ryan Arena, Evanston, Illinois": SportsballGeocodeTuple(
        city="Evanston",
        state="IL",
        postal="60201",
        lat=42.066944,
        lng=-87.692778,
        housenumber="2705",
        country="USA",
    ),
    "Gentry Center Complex, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.168889,
        lng=-86.829444,
        housenumber="",
        country="USA",
    ),
    "Eblen Center, Cookeville, Tennessee": SportsballGeocodeTuple(
        city="Cookeville",
        state="TN",
        postal="",
        lat=36.178508,
        lng=-85.51,
        housenumber="1100",
        country="USA",
    ),
    "The Thunderdome, Santa Barbara, California": SportsballGeocodeTuple(
        city="Santa Barbara",
        state="CA",
        postal="",
        lat=34.413792,
        lng=-119.851147,
        housenumber="",
        country="USA",
    ),
    "Jenny Craig Pavillion, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.7745,
        lng=-117.1837,
        housenumber="5998",
        country="USA",
    ),
    "Physical Education Complex, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="21216",
        lat=39.315453,
        lng=-76.657381,
        housenumber="2500",
        country="USA",
    ),
    "Estelle and Zoom Fleisher Athletic Center, Newark, New Jersey": SportsballGeocodeTuple(
        city="Newark",
        state="NJ",
        postal="",
        lat=40.743125,
        lng=-74.182161,
        housenumber="",
        country="USA",
    ),
    "SEFCU Arena, Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="12222",
        lat=42.681667,
        lng=-73.828333,
        housenumber="1400",
        country="USA",
    ),
    "Knights Hall, Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="40205",
        lat=38.2215197,
        lng=-85.7077667,
        housenumber="2000",
        country="USA",
    ),
    "Alico Arena, Fort Myers, Florida": SportsballGeocodeTuple(
        city="Fort Myers",
        state="FL",
        postal="",
        lat=26.471111,
        lng=-81.764722,
        housenumber="",
        country="USA",
    ),
    "The HTC Center, Conway, South Carolina": SportsballGeocodeTuple(
        city="Conway",
        state="SC",
        postal="29579",
        lat=33.799167,
        lng=-79.015556,
        housenumber="104",
        country="USA",
    ),
    "Daskalakis Athletic Center, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="",
        lat=39.956389,
        lng=-75.190833,
        housenumber="",
        country="USA",
    ),
    "Leo D. Mahoney Arena, Fairfield, Connecticut": SportsballGeocodeTuple(
        city="Fairfield",
        state="CT",
        postal="06824",
        lat=41.159722,
        lng=-73.256667,
        housenumber="",
        country="USA",
    ),
    "Convocation Center, Hampton, Virginia": SportsballGeocodeTuple(
        city="Hampton",
        state="VA",
        postal="23668",
        lat=37.01974,
        lng=-76.33108,
        housenumber="100",
        country="USA",
    ),
    "Hynes Athletics Center, New Rochelle, New York": SportsballGeocodeTuple(
        city="New Rochelle",
        state="NY",
        postal="",
        lat=40.92664,
        lng=-73.784325,
        housenumber="",
        country="USA",
    ),
    "Swisher Gymnasium, Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32211",
        lat=30.350278,
        lng=-81.605,
        housenumber="1",
        country="USA",
    ),
    "Pete Mathews Coliseum, Jacksonville, Alabama": SportsballGeocodeTuple(
        city="Jacksonville",
        state="AL",
        postal="36265",
        lat=33.824,
        lng=-85.773,
        housenumber="700",
        country="USA",
    ),
    "Atlantic Union Bank Center, Harrisonburg, Virginia": SportsballGeocodeTuple(
        city="Harrisonburg",
        state="VA",
        postal="",
        lat=38.430437,
        lng=-78.859574,
        housenumber="645",
        country="USA",
    ),
    "KSU Convocation Center , Kennesaw, Georgia": SportsballGeocodeTuple(
        city="Kennesaw",
        state="GA",
        postal="30144",
        lat=34.036924,
        lng=-84.580329,
        housenumber="590",
        country="USA",
    ),
    "Ellis T. Johnson Arena, Morehead, Kentucky": SportsballGeocodeTuple(
        city="Morehead",
        state="KY",
        postal="40351",
        lat=38.188786,
        lng=-83.429006,
        housenumber="111",
        country="USA",
    ),
    "Ellis Corbett Sports Center, Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="27411",
        lat=36.076783,
        lng=-79.768849,
        housenumber="1601",
        country="USA",
    ),
    "Trask Coliseum, Wilmington, North Carolina": SportsballGeocodeTuple(
        city="Wilmington",
        state="NC",
        postal="",
        lat=34.225,
        lng=-77.878333,
        housenumber="",
        country="USA",
    ),
    "UNF Arena , Jacksonville, Florida": SportsballGeocodeTuple(
        city="Jacksonville",
        state="FL",
        postal="32224",
        lat=30.2734,
        lng=-81.5079,
        housenumber="11852",
        country="USA",
    ),
    "Alumni Gymnasium, Lawrenceville, New Jersey": SportsballGeocodeTuple(
        city="Lawrenceville",
        state="NJ",
        postal="",
        lat=40.2788,
        lng=-74.7354,
        housenumber="",
        country="USA",
    ),
    "MVP Arena, Albany, New York": SportsballGeocodeTuple(
        city="Albany",
        state="NY",
        postal="",
        lat=42.648611,
        lng=-73.754722,
        housenumber="51",
        country="USA",
    ),
    "SECU Arena, Towson, Maryland": SportsballGeocodeTuple(
        city="Towson",
        state="MD",
        postal="21252",
        lat=39.387361,
        lng=-76.617083,
        housenumber="8000",
        country="USA",
    ),
    "Roy L. Patrick Gymnasium, Burlington, Vermont": SportsballGeocodeTuple(
        city="Burlington",
        state="VT",
        postal="",
        lat=44.470264,
        lng=-73.194705,
        housenumber="97",
        country="USA",
    ),
    "Convocation Center, Jonesboro, Arkansas": SportsballGeocodeTuple(
        city="Jonesboro",
        state="AK",
        postal="72401",
        lat=35.845422,
        lng=-90.670319,
        housenumber="217",
        country="USA",
    ),
    "Reed Gym, Pocatello, Idaho": SportsballGeocodeTuple(
        city="Pocatello",
        state="ID",
        postal="",
        lat=42.8645,
        lng=-112.429,
        housenumber="936",
        country="USA",
    ),
    "Scheels Center, Fargo, North Dakota": SportsballGeocodeTuple(
        city="Fargo",
        state="ND",
        postal="",
        lat=46.900442,
        lng=-96.799025,
        housenumber="1600",
        country="USA",
    ),
    "Findlay Toyota Court at Walkup Skydome, Flagstaff, Arizona": SportsballGeocodeTuple(
        city="Flagstaff",
        state="AZ",
        postal="",
        lat=35.1805,
        lng=-111.6525,
        housenumber="",
        country="USA",
    ),
    "Sanford Coyote Sports Center, Vermillon, South Dakota": SportsballGeocodeTuple(
        city="Vermillon",
        state="SD",
        postal="57069",
        lat=42.790111,
        lng=-96.927806,
        housenumber="",
        country="USA",
    ),
    "Screaming Eagles Arena, Evansville, Indiana": SportsballGeocodeTuple(
        city="Evansville",
        state="IN",
        postal="47712",
        lat=37.961944,
        lng=-87.674722,
        housenumber="8600",
        country="USA",
    ),
    "Wisdom Gym, Stephenville, Texas": SportsballGeocodeTuple(
        city="Stephenville",
        state="TX",
        postal="",
        lat=32.215438,
        lng=-98.220617,
        housenumber="",
        country="USA",
    ),
    "Skyhawk Arena, Martin, Tennessee": SportsballGeocodeTuple(
        city="Martin",
        state="TN",
        postal="",
        lat=36.343648,
        lng=-88.867185,
        housenumber="95",
        country="USA",
    ),
    "College Park Center, Arlington, Texas": SportsballGeocodeTuple(
        city="Arlington",
        state="TX",
        postal="76019",
        lat=32.730586,
        lng=-97.107972,
        housenumber="600",
        country="USA",
    ),
    "GCU Arena, Phoenix, Arizona": SportsballGeocodeTuple(
        city="Phoenix",
        state="AZ",
        postal="85017",
        lat=33.510152,
        lng=-112.128884,
        housenumber="3300",
        country="USA",
    ),
    "Liberty Arena, Lynchburg, Virginia": SportsballGeocodeTuple(
        city="Lynchburg",
        state="VA",
        postal="",
        lat=37.349356,
        lng=-79.180225,
        housenumber="",
        country="USA",
    ),
    "Bank of Colorado Arena, Greeley, Colorado": SportsballGeocodeTuple(
        city="Greeley",
        state="CO",
        postal="80639",
        lat=40.402217,
        lng=-104.703044,
        housenumber="270",
        country="USA",
    ),
    "Dee Events Center, Ogden, Utah": SportsballGeocodeTuple(
        city="Ogden",
        state="UT",
        postal="",
        lat=41.1825,
        lng=-111.945,
        housenumber="4400",
        country="USA",
    ),
    "Robert A. Mott Athletics Center, San Luis Obispo, California": SportsballGeocodeTuple(
        city="San Luis Obispo",
        state="CA",
        postal="93407",
        lat=35.29886,
        lng=-120.65855,
        housenumber="1",
        country="USA",
    ),
    "Bren Events Center, Irvine, California": SportsballGeocodeTuple(
        city="Irvine",
        state="CA",
        postal="92612",
        lat=33.649167,
        lng=-117.846944,
        housenumber="100",
        country="USA",
    ),
    "The Walter Pyramid, Long Beach, California": SportsballGeocodeTuple(
        city="Long Beach",
        state="CA",
        postal="90840",
        lat=33.787222,
        lng=-118.114167,
        housenumber="1250",
        country="USA",
    ),
    "Albert Gersten Pavilion, Los Angeles, California": SportsballGeocodeTuple(
        city="Los Angeles",
        state="CA",
        postal="90045",
        lat=33.9675,
        lng=-118.415556,
        housenumber="1",
        country="USA",
    ),
    "Firestone Fieldhouse, Malibu, California": SportsballGeocodeTuple(
        city="Malibu",
        state="CA",
        postal="",
        lat=34.038571,
        lng=-118.709625,
        housenumber="",
        country="USA",
    ),
    "Chiles Center, Portland, Oregon": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="",
        lat=45.575,
        lng=-122.728,
        housenumber="",
        country="USA",
    ),
    "Redhawk Center, Seattle, Washington": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="",
        lat=47.607222,
        lng=-122.313333,
        housenumber="",
        country="USA",
    ),
    "James H. Hilton Coliseum , Ames, Iowa": SportsballGeocodeTuple(
        city="Ames",
        state="IA",
        postal="50010",
        lat=42.02101,
        lng=-93.634763,
        housenumber="",
        country="USA",
    ),
    "Thompson-Boling Arena, Knoxville, Tennessee": SportsballGeocodeTuple(
        city="Knoxville",
        state="TN",
        postal="37916",
        lat=35.951167,
        lng=-83.925028,
        housenumber="1600",
        country="USA",
    ),
    "Hofheinz Pavilion, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77004",
        lat=29.724722,
        lng=-95.346944,
        housenumber="3875",
        country="USA",
    ),
    "Breslin Events Center, East Lansing, Michigan": SportsballGeocodeTuple(
        city="East Lansing",
        state="MI",
        postal="48824",
        lat=42.728227,
        lng=-84.492396,
        housenumber="534",
        country="USA",
    ),
    "Alaska Airlines Arena, Seattle, Washington": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="",
        lat=47.652,
        lng=-122.302,
        housenumber="3870",
        country="USA",
    ),
    "Thomas & Mack Center, Las Vegas, Nevada": THOMAS_AND_MACK_CENTER,
    "Christl Arena, West Point, New York": SportsballGeocodeTuple(
        city="West Point",
        state="NY",
        postal="10996",
        lat=41.38641,
        lng=-73.96571,
        housenumber="600",
        country="USA",
    ),
    "The McKenzie Arena, Chattanooga, Tennessee": SportsballGeocodeTuple(
        city="Chattanooga",
        state="TN",
        postal="37403",
        lat=35.050382,
        lng=-85.30091,
        housenumber="720",
        country="USA",
    ),
    "University of Dayton Arena, Dayton, Ohio": SportsballGeocodeTuple(
        city="Dayton",
        state="OH",
        postal="45417",
        lat=39.7348749,
        lng=-84.2021489,
        housenumber="1801",
        country="USA",
    ),
    "John Glaser Arena, Philadelphia, Pennsylvania": JOHN_GLASER_ARENA,
    "University Center, Hammond, Louisiana": SportsballGeocodeTuple(
        city="Hammond",
        state="LA",
        postal="70401",
        lat=30.52,
        lng=-90.472778,
        housenumber="",
        country="USA",
    ),
    "Donald N. Dedmon Center, Radford, Virginia": SportsballGeocodeTuple(
        city="Radford",
        state="VA",
        postal="24141",
        lat=37.1386,
        lng=-80.541769,
        housenumber="101",
        country="USA",
    ),
    "Knapp Center, Des Moines, Iowa": SportsballGeocodeTuple(
        city="Des Moines",
        state="IA",
        postal="50311",
        lat=41.604444,
        lng=-93.651944,
        housenumber="2601",
        country="USA",
    ),
    "Joseph J. Gentile Center, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60626",
        lat=42.000556,
        lng=-87.658889,
        housenumber="6525",
        country="USA",
    ),
    "JQH Arena, Springfield, Missouri": SportsballGeocodeTuple(
        city="Springfield",
        state="MO",
        postal="65897",
        lat=37.2021052,
        lng=-93.2855636,
        housenumber="685",
        country="USA",
    ),
    "Case Gym, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="",
        lat=42.353932,
        lng=-71.120355,
        housenumber="285",
        country="USA",
    ),
    "Kimmel Arena, Asheville, North Carolina": SportsballGeocodeTuple(
        city="Asheville",
        state="NC",
        postal="28804",
        lat=35.6181,
        lng=-82.5689,
        housenumber="227",
        country="USA",
    ),
    "Memorial Gymnasium, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37235",
        lat=36.144611,
        lng=-86.80742,
        housenumber="",
        country="USA",
    ),
    "Cameron Hall, Lexington, Virginia": SportsballGeocodeTuple(
        city="Lexington",
        state="VA",
        postal="24450",
        lat=37.788333,
        lng=-79.436389,
        housenumber="401",
        country="USA",
    ),
    "Lawrence Joel Coliseum, Winston-Salem, North Carolina": SportsballGeocodeTuple(
        city="Winston-Salem",
        state="NC",
        postal="27105",
        lat=36.127866,
        lng=-80.257628,
        housenumber="2825",
        country="USA",
    ),
    "Winthrop Coliseum, Rock Hill, South Carolina": SportsballGeocodeTuple(
        city="Rock Hill",
        state="SC",
        postal="29730",
        lat=34.947911,
        lng=-81.014972,
        housenumber="1162",
        country="USA",
    ),
    "Sojka Pavilion, Lewisburg, Pennsylvania": SportsballGeocodeTuple(
        city="Lewisburg",
        state="PA",
        postal="17837",
        lat=40.956964,
        lng=-76.887093,
        housenumber="701",
        country="USA",
    ),
    "Hinkle Fieldhouse, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.843611,
        lng=-86.167222,
        housenumber="510",
        country="USA",
    ),
    "Henry J. Goodman Arena, Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.499167,
        lng=-81.676944,
        housenumber="2000",
        country="USA",
    ),
    "Rose Hill Gym, Bronx, New York": SportsballGeocodeTuple(
        city="Bronx",
        state="NY",
        postal="10458",
        lat=40.862148,
        lng=-73.883824,
        housenumber="",
        country="USA",
    ),
    "Bon Secours Wellness Arena, Greenville, South Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="SC",
        postal="",
        lat=34.852789,
        lng=-82.391458,
        housenumber="650",
        country="USA",
    ),
    "Charles E. Smith Center, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="20052",
        lat=38.897755,
        lng=-77.049329,
        housenumber="600",
        country="USA",
    ),
    "Burr Gymnasium, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.9264,
        lng=-77.0221,
        housenumber="",
        country="USA",
    ),
    "Fant-Ewing Coliseum, Monroe, Louisiana": SportsballGeocodeTuple(
        city="Monroe",
        state="LA",
        postal="",
        lat=32.531,
        lng=-92.069,
        housenumber="4319",
        country="USA",
    ),
    "Alumni Hall, Annapolis, Maryland": SportsballGeocodeTuple(
        city="Annapolis",
        state="MD",
        postal="21402",
        lat=38.984491,
        lng=-76.487782,
        housenumber="461",
        country="USA",
    ),
    "Dean Smith Center, Chapel Hill, North Carolina": SportsballGeocodeTuple(
        city="Chapel Hill",
        state="NC",
        postal="",
        lat=35.899722,
        lng=-79.043889,
        housenumber="300",
        country="USA",
    ),
    "Greensboro Coliseum, Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="",
        lat=36.059722,
        lng=-79.825556,
        housenumber="1921",
        country="USA",
    ),
    "Athletics Center O'rena, Rochester, Michigan": SportsballGeocodeTuple(
        city="Rochester",
        state="MI",
        postal="",
        lat=42.673972,
        lng=-83.213158,
        housenumber="",
        country="USA",
    ),
    "Yuengling Center, Tampa, Florida": SportsballGeocodeTuple(
        city="Tampa",
        state="FL",
        postal="",
        lat=28.059236,
        lng=-82.406472,
        housenumber="12499",
        country="USA",
    ),
    "Reilly Center, St. Bonaventure, New York": SportsballGeocodeTuple(
        city="St. Bonaventure",
        state="NY",
        postal="",
        lat=42.079428,
        lng=-78.484998,
        housenumber="",
        country="USA",
    ),
    "Devlin Fieldhouse, New Orleans, Louisiana": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="70118",
        lat=29.938611,
        lng=-90.120556,
        housenumber="",
        country="USA",
    ),
    "Cassell Coliseum, Blacksburg, Virginia": SportsballGeocodeTuple(
        city="Blacksburg",
        state="VA",
        postal="",
        lat=37.222222,
        lng=-80.418889,
        housenumber="675",
        country="USA",
    ),
    "Ervin J. Nutter Center, Dayton, Ohio": SportsballGeocodeTuple(
        city="Dayton",
        state="OH",
        postal="",
        lat=39.781944,
        lng=-84.0525,
        housenumber="3640",
        country="USA",
    ),
    "Carver Arena, Peoria, Illinois": SportsballGeocodeTuple(
        city="Peoria",
        state="IL",
        postal="61602-1423",
        lat=40.691667,
        lng=-89.594167,
        housenumber="201",
        country="USA",
    ),
    "UIC Pavilion, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60607",
        lat=41.874722,
        lng=-87.656111,
        housenumber="525",
        country="USA",
    ),
    "Mitchell Center, Mobile, Alabama": SportsballGeocodeTuple(
        city="Mobile",
        state="AL",
        postal="36608",
        lat=30.69229,
        lng=-88.17975,
        housenumber="2195",
        country="USA",
    ),
    "Ed & Rae Schollmaier Arena, Fort Worth, Texas": SportsballGeocodeTuple(
        city="Fort Worth",
        state="TX",
        postal="76109",
        lat=32.708774,
        lng=-97.36673,
        housenumber="2900",
        country="USA",
    ),
    "Strahan Coliseum, San Marcos, Texas": SportsballGeocodeTuple(
        city="San Marcos",
        state="TX",
        postal="78666",
        lat=29.888611,
        lng=-97.932778,
        housenumber="601",
        country="USA",
    ),
    "Coors Events/Conference Center, Boulder, Colorado": SportsballGeocodeTuple(
        city="Boulder",
        state="CO",
        postal="",
        lat=40.0047,
        lng=-105.2606,
        housenumber="950",
        country="USA",
    ),
    "Hamilton Gymnasium, Denver, Colorado": SportsballGeocodeTuple(
        city="Denver",
        state="CO",
        postal="",
        lat=39.682106,
        lng=-104.961592,
        housenumber="2240",
        country="USA",
    ),
    "Donald L. Tucker Center, Tallahassee, Florida": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="32301-1619",
        lat=30.437842,
        lng=-84.28669,
        housenumber="505",
        country="USA",
    ),
    "John Paul Jones Arena, Charlottesville, Virginia": SportsballGeocodeTuple(
        city="Charlottesville",
        state="VA",
        postal="22903",
        lat=38.046,
        lng=-78.5068,
        housenumber="295",
        country="USA",
    ),
    "Lloyd Noble Center, Norman, Oklahoma": SportsballGeocodeTuple(
        city="Norman",
        state="OK",
        postal="73072",
        lat=35.1875,
        lng=-97.444444,
        housenumber="2900",
        country="USA",
    ),
    "Brown Stadium (RI) - Providence - RI - 02906": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="02906",
        lat=41.842222,
        lng=-71.394444,
        housenumber="400",
        country="USA",
    ),
    "Auburn Arena, Auburn, Alabama": SportsballGeocodeTuple(
        city="Auburn",
        state="AL",
        postal="36849",
        lat=32.60253,
        lng=-85.49301,
        housenumber="250",
        country="USA",
    ),
    "Cameron Indoor Stadium, Durham, North Carolina": SportsballGeocodeTuple(
        city="Durham",
        state="NC",
        postal="",
        lat=35.9976,
        lng=-78.9422,
        housenumber="115",
        country="USA",
    ),
    "Coleman Coliseum , Tuscaloosa, Alabama": SportsballGeocodeTuple(
        city="Tuscaloosa",
        state="AL",
        postal="35487",
        lat=33.202939,
        lng=-87.539706,
        housenumber="1201",
        country="USA",
    ),
    "Stephen C. O'Connell Center, Gainesville, Florida": SportsballGeocodeTuple(
        city="Gainesville",
        state="FL",
        postal="32611",
        lat=29.649444,
        lng=-82.351111,
        housenumber="250",
        country="USA",
    ),
    "Wintrust Arena, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="",
        lat=41.853611,
        lng=-87.621389,
        housenumber="200",
        country="USA",
    ),
    "Rupp Arena, Lexington, Kentucky": SportsballGeocodeTuple(
        city="Lexington",
        state="KY",
        postal="40506",
        lat=38.049444,
        lng=-84.502778,
        housenumber="432",
        country="USA",
    ),
    "Assembly Hall, Bloomington, Indiana": SportsballGeocodeTuple(
        city="Bloomington",
        state="IN",
        postal="47408-1590",
        lat=39.180833,
        lng=-86.522222,
        housenumber="1001",
        country="USA",
    ),
    "Kohl Center, Madison, Wisconsin": SportsballGeocodeTuple(
        city="Madison",
        state="WI",
        postal="53715-1206",
        lat=43.06942,
        lng=-89.396972,
        housenumber="601",
        country="USA",
    ),
    "McKale Center, Tucson, Arizona": SportsballGeocodeTuple(
        city="Tucson",
        state="AZ",
        postal="",
        lat=32.23,
        lng=-110.95,
        housenumber="1",
        country="USA",
    ),
    "Memorial Athletic & Convocation Center, Kent, Ohio": SportsballGeocodeTuple(
        city="Kent",
        state="OH",
        postal="44242",
        lat=41.148,
        lng=-81.344,
        housenumber="1025",
        country="USA",
    ),
    "Madison Square Garden (IV), New York, New York": MADISON_SQUARE_GARDEN,
    "Stuart Siegel Center, Richmond, Virginia": SportsballGeocodeTuple(
        city="Richmond",
        state="VA",
        postal="23284",
        lat=37.552918,
        lng=-77.4529,
        housenumber="1200",
        country="USA",
    ),
    "Curb Event Center, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="37212",
        lat=36.132222,
        lng=-86.794444,
        housenumber="2002",
        country="USA",
    ),
    "Bramlage Coliseum, Manhattan, Kansas": SportsballGeocodeTuple(
        city="Manhattan",
        state="KS",
        postal="66502",
        lat=39.200361,
        lng=-96.593833,
        housenumber="1800",
        country="USA",
    ),
    "Convocation Center, DeKalb, Illinois": SportsballGeocodeTuple(
        city="DeKalb",
        state="IL",
        postal="60115-2854",
        lat=41.935106,
        lng=-88.785569,
        housenumber="1525",
        country="USA",
    ),
    "McLeod Center, Cedar Falls, Iowa": SportsballGeocodeTuple(
        city="Cedar Falls",
        state="IO",
        postal="",
        lat=42.51395,
        lng=-92.46714,
        housenumber="",
        country="USA",
    ),
    "Desert Financial Arena, Tempe, Arizona": SportsballGeocodeTuple(
        city="Tempe",
        state="AZ",
        postal="",
        lat=33.424524,
        lng=-111.930948,
        housenumber="600",
        country="USA",
    ),
    "Lawlor Events Center, Reno, Nevada": SportsballGeocodeTuple(
        city="Reno",
        state="NV",
        postal="",
        lat=39.545069,
        lng=-119.818269,
        housenumber="1500",
        country="USA",
    ),
    "San Jose State Event Center, San Jose, California": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="95192",
        lat=37.33536,
        lng=-121.87985,
        housenumber="290",
        country="USA",
    ),
    "Galen Center, Los Angeles, California": SportsballGeocodeTuple(
        city="Los Angeles",
        state="CA",
        postal="",
        lat=34.021,
        lng=-118.28,
        housenumber="3400",
        country="USA",
    ),
    "Cintas Center, Cincinnati, Ohio": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="45207",
        lat=39.150148,
        lng=-84.471881,
        housenumber="1624",
        country="USA",
    ),
    "Stroh Center, Bowling Green, Ohio": SportsballGeocodeTuple(
        city="Bowling Green",
        state="OH",
        postal="43402",
        lat=41.375343,
        lng=-83.624711,
        housenumber="1535",
        country="USA",
    ),
    "McGuirk Arena, Mt. Pleasant, Michigan": SportsballGeocodeTuple(
        city="Mt. Pleasant",
        state="MI",
        postal="",
        lat=43.580888,
        lng=-84.773941,
        housenumber="",
        country="USA",
    ),
    "Williams Arena at Minges Coliseum, Greenville, North Carolina": SportsballGeocodeTuple(
        city="Greenville",
        state="NC",
        postal="27858",
        lat=35.597391,
        lng=-77.367167,
        housenumber="1",
        country="USA",
    ),
    "Convocation Center, Athens, Ohio": SportsballGeocodeTuple(
        city="Athens",
        state="OH",
        postal="45701",
        lat=39.323056,
        lng=-82.105556,
        housenumber="95",
        country="USA",
    ),
    "Carrier Dome, Syracuse, New York": SportsballGeocodeTuple(
        city="Syracuse",
        state="NY",
        postal="",
        lat=43.036111,
        lng=-76.136389,
        housenumber="900",
        country="USA",
    ),
    "Charles Koch Arena, Wichita, Kansas": SportsballGeocodeTuple(
        city="Wichita",
        state="KS",
        postal="67260",
        lat=37.721667,
        lng=-97.2975,
        housenumber="",
        country="USA",
    ),
    "CHI Health Center Omaha, Omaha, Nebraska": SportsballGeocodeTuple(
        city="Omaha",
        state="NB",
        postal="",
        lat=41.263,
        lng=-95.928,
        housenumber="455",
        country="USA",
    ),
    "Tudor Fieldhouse, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77251",
        lat=29.715102,
        lng=-95.403895,
        housenumber="6100",
        country="USA",
    ),
    "Show Me Center, Cape Girardeau, Missouri": SportsballGeocodeTuple(
        city="Cape Girardeau",
        state="MO",
        postal="63701",
        lat=37.32,
        lng=-89.5271,
        housenumber="1333",
        country="USA",
    ),
    "ExtraMile Arena, Boise, Idaho": SportsballGeocodeTuple(
        city="Boise",
        state="ID",
        postal="",
        lat=43.6035,
        lng=-116.199,
        housenumber="1401",
        country="USA",
    ),
    "Marriott Center, Provo, Utah": SportsballGeocodeTuple(
        city="Provo",
        state="UT",
        postal="",
        lat=40.254,
        lng=-111.649,
        housenumber="701",
        country="USA",
    ),
    "McCamish Pavilion, Atlanta, Georgia": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="",
        lat=33.780833,
        lng=-84.392778,
        housenumber="965",
        country="USA",
    ),
    "Maravich Assembly Center, Baton Rouge, Louisiana": SportsballGeocodeTuple(
        city="Baton Rouge",
        state="LA",
        postal="",
        lat=30.4142,
        lng=-91.1845,
        housenumber="",
        country="USA",
    ),
    "Viejas Arena, San Diego, California": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.77375,
        lng=-117.074583,
        housenumber="5500",
        country="USA",
    ),
    "Reitz Arena, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.346803,
        lng=-76.618615,
        housenumber="4501",
        country="USA",
    ),
    "Xfinity Center, College Park, Maryland": SportsballGeocodeTuple(
        city="College Park",
        state="MD",
        postal="",
        lat=38.995278,
        lng=-76.941389,
        housenumber="",
        country="USA",
    ),
    "Rutgers Athletic Center, New Brunswick, New Jersey": SportsballGeocodeTuple(
        city="New Brunswick",
        state="NJ",
        postal="08854",
        lat=40.525278,
        lng=-74.441111,
        housenumber="83",
        country="USA",
    ),
    "Davey L. Whitney Complex, Alcorn State, Mississippi": SportsballGeocodeTuple(
        city="Alcorn State",
        state="MI",
        postal="",
        lat=31.873225,
        lng=-91.13318,
        housenumber="",
        country="USA",
    ),
    "H.O. Clemmons Arena, Pine Bluff, Arkansas": SportsballGeocodeTuple(
        city="Pine Bluff",
        state="AK",
        postal="",
        lat=34.243825,
        lng=-92.017429,
        housenumber="",
        country="USA",
    ),
    "Assembly Center, Grambling, Louisiana": SportsballGeocodeTuple(
        city="Grambling",
        state="LA",
        postal="",
        lat=32.520284,
        lng=-92.723578,
        housenumber="1234",
        country="USA",
    ),
    "McDermott Center, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="",
        lat=29.468139,
        lng=-98.469417,
        housenumber="",
        country="USA",
    ),
    "Lee E. Williams Athletics and Assembly Center, Jackson, Mississippi": SportsballGeocodeTuple(
        city="Jackson",
        state="MI",
        postal="39217",
        lat=32.299724,
        lng=-90.211887,
        housenumber="1400",
        country="USA",
    ),
    "Harrison HPER Complex, Itta Bena, Mississippi": SportsballGeocodeTuple(
        city="Itta Bena",
        state="MI",
        postal="",
        lat=33.51406,
        lng=-90.189362,
        housenumber="",
        country="USA",
    ),
    "Hill Field House, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.3425,
        lng=-76.585,
        housenumber="1700",
        country="USA",
    ),
    "McLendon-McDougald Gym, Durham, North Carolina": SportsballGeocodeTuple(
        city="Durham",
        state="NC",
        postal="27707",
        lat=35.975884,
        lng=-78.897745,
        housenumber="1801",
        country="USA",
    ),
    "Purcell Pavilion at the Joyce Center, South Bend, Indiana": SportsballGeocodeTuple(
        city="South Bend",
        state="IN",
        postal="46556",
        lat=41.698443,
        lng=-86.231292,
        housenumber="",
        country="USA",
    ),
    "SHM Memorial Center, Orangeburg, South Carolina": SportsballGeocodeTuple(
        city="Orangeburg",
        state="SC",
        postal="29117",
        lat=33.500979,
        lng=-80.846522,
        housenumber="300",
        country="USA",
    ),
    "William Johnson Coliseum, Nacogdoches, Texas": SportsballGeocodeTuple(
        city="Nacogdoches",
        state="TX",
        postal="75964",
        lat=31.622222,
        lng=-94.640833,
        housenumber="700",
        country="USA",
    ),
    "UTRGV Fieldhouse, Edinburg, Texas": SportsballGeocodeTuple(
        city="Edinburg",
        state="TX",
        postal="",
        lat=26.310278,
        lng=-98.178056,
        housenumber="",
        country="USA",
    ),
    "Frank and Lucille Sharp Gymnasium, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="77074",
        lat=29.41,
        lng=-95.31,
        housenumber="7502",
        country="USA",
    ),
    "Montagne Center, Beaumont, Texas": SportsballGeocodeTuple(
        city="Beaumont",
        state="TX",
        postal="77710",
        lat=30.2,
        lng=-94.4,
        housenumber="4400",
        country="USA",
    ),
    "F. G. Clark Activity Center, Baton Rouge, Louisiana": SportsballGeocodeTuple(
        city="Baton Rouge",
        state="LA",
        postal="",
        lat=30.521667,
        lng=-91.185556,
        housenumber="",
        country="USA",
    ),
    "American Bank Center, Corpus Christi, Texas": SportsballGeocodeTuple(
        city="Corpus Christi",
        state="TX",
        postal="",
        lat=27.807339,
        lng=-97.393561,
        housenumber="1901",
        country="USA",
    ),
    "Schar Center, Elon, North Carolina": SportsballGeocodeTuple(
        city="Elon",
        state="NC",
        postal="",
        lat=36.10805,
        lng=-79.51084,
        housenumber="",
        country="USA",
    ),
    "Bryce Jordan Center, University Park, Pennsylvania": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="16802",
        lat=40.79578,
        lng=-77.869399,
        housenumber="",
        country="USA",
    ),
    "Mackey Arena, West Lafayette, Indiana": SportsballGeocodeTuple(
        city="West Lafayette",
        state="IN",
        postal="47907",
        lat=40.433322,
        lng=-86.916144,
        housenumber="900",
        country="USA",
    ),
    "Crisler Arena, Ann Arbor, Michigan": SportsballGeocodeTuple(
        city="Ann Arbor",
        state="MI",
        postal="48104",
        lat=42.265037,
        lng=-83.746768,
        housenumber="333",
        country="USA",
    ),
    "FAU Arena, Boca Raton, Florida": SportsballGeocodeTuple(
        city="Boca Raton",
        state="FL",
        postal="33431",
        lat=26.372222,
        lng=-80.109167,
        housenumber="777",
        country="USA",
    ),
    "Hammel Court, North Andover, Massachusetts": SportsballGeocodeTuple(
        city="North Andover",
        state="MA",
        postal="",
        lat=42.667843,
        lng=-71.119995,
        housenumber="",
        country="USA",
    ),
    "Koessler Athletic Center, Buffalo, New York": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="14208",
        lat=42.920919,
        lng=-78.85754,
        housenumber="1829",
        country="USA",
    ),
    "Detrick Gymnasium, New Britain, Connecticut": SportsballGeocodeTuple(
        city="New Britain",
        state="CT",
        postal="06053",
        lat=41.693,
        lng=-72.7649,
        housenumber="1615",
        country="USA",
    ),
    "Bogota Savings Bank Center, Teaneck, New Jersey": SportsballGeocodeTuple(
        city="Teaneck",
        state="NJ",
        postal="07601",
        lat=40.8967,
        lng=-74.0324,
        housenumber="",
        country="USA",
    ),
    "Emil and Patricia Jones Convocation Center, Chicago, Illinois": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60628",
        lat=41.7165,
        lng=-87.6084,
        housenumber="9501",
        country="USA",
    ),
    "McCann Recreation Center, Poughkeepsie, New York": SportsballGeocodeTuple(
        city="Poughkeepsie",
        state="NY",
        postal="",
        lat=41.718431,
        lng=-73.934,
        housenumber="",
        country="USA",
    ),
    "Knott Arena, Emmitsburg, Maryland": SportsballGeocodeTuple(
        city="Emmitsburg",
        state="MD",
        postal="21727",
        lat=39.679492,
        lng=-77.346435,
        housenumber="16300",
        country="USA",
    ),
    "Gallagher Center, Niagara University, New York": SportsballGeocodeTuple(
        city="Niagara University",
        state="NY",
        postal="14109",
        lat=43.137035,
        lng=-79.038026,
        housenumber="2009",
        country="USA",
    ),
    "UPMC Events Center, Moon, Pennsylvania": SportsballGeocodeTuple(
        city="Moon",
        state="PA",
        postal="",
        lat=40.520212,
        lng=-80.21476,
        housenumber="",
        country="USA",
    ),
    "Donald W. Reynolds Center, Tulsa, Oklahoma": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="74104",
        lat=36.148611,
        lng=-95.941944,
        housenumber="800",
        country="USA",
    ),
    "Ramsey Center, Cullowhee, North Carolina": SportsballGeocodeTuple(
        city="Cullowhee",
        state="NC",
        postal="28723",
        lat=35.3037,
        lng=-83.1823,
        housenumber="92",
        country="USA",
    ),
    "Jack Stephens Center, Little Rock, Arkansas": SportsballGeocodeTuple(
        city="Little Rock",
        state="AK",
        postal="72204",
        lat=34.727778,
        lng=-92.339722,
        housenumber="2801",
        country="USA",
    ),
    "Moody Center, Austin, Texas": SportsballGeocodeTuple(
        city="Austin",
        state="TX",
        postal="",
        lat=30.280972,
        lng=-97.730472,
        housenumber="2001",
        country="USA",
    ),
    "The Colonial Life Arena, Columbia, South Carolina": SportsballGeocodeTuple(
        city="Columbia",
        state="SC",
        postal="",
        lat=33.995,
        lng=-81.037222,
        housenumber="801",
        country="USA",
    ),
    "United Supermarkets Arena, Lubbock, Texas": SportsballGeocodeTuple(
        city="Lubbock",
        state="TX",
        postal="79409",
        lat=33.581261,
        lng=-101.886636,
        housenumber="1701",
        country="USA",
    ),
    "Reed Arena, College Station, Texas": SportsballGeocodeTuple(
        city="College Station",
        state="TX",
        postal="77843",
        lat=30.60578,
        lng=-96.34619,
        housenumber="730",
        country="USA",
    ),
    "Humphrey Coliseum, Starkville, Mississippi": SportsballGeocodeTuple(
        city="Starkville",
        state="MS",
        postal="39762",
        lat=33.461667,
        lng=-88.794444,
        housenumber="55",
        country="USA",
    ),
    "Bud Walton Arena, Fayetteville, Arkansas": SportsballGeocodeTuple(
        city="Fayetteville",
        state="AK",
        postal="72701-5570",
        lat=36.061518,
        lng=-94.178188,
        housenumber="1270",
        country="USA",
    ),
    "Fifth Third Arena, Cincinnati, Ohio": SportsballGeocodeTuple(
        city="Cincinnati",
        state="OH",
        postal="45221",
        lat=39.131101,
        lng=-84.514207,
        housenumber="2700",
        country="USA",
    ),
    "State Farm Center, Champaign, Illinois": SportsballGeocodeTuple(
        city="Champaign",
        state="IL",
        postal="",
        lat=40.096259,
        lng=-88.235956,
        housenumber="1800",
        country="USA",
    ),
    "Stegeman Coliseum, Athens, Georgia": SportsballGeocodeTuple(
        city="Athens",
        state="GA",
        postal="30605",
        lat=33.9428,
        lng=-83.378,
        housenumber="100",
        country="USA",
    ),
    "McCarthey Athletic Center, Spokane, Washington": SportsballGeocodeTuple(
        city="Spokane",
        state="WA",
        postal="",
        lat=47.665,
        lng=-117.399,
        housenumber="801",
        country="USA",
    ),
    "FedExForum, Memphis, Tennessee": FEDEX_FORUM,
    "The Pavilion at Ole Miss, Oxford, Mississippi": SportsballGeocodeTuple(
        city="Oxford",
        state="MS",
        postal="38677",
        lat=34.363164,
        lng=-89.535453,
        housenumber="",
        country="USA",
    ),
    "Dee Glen Smith Spectrum, Logan, Utah": SportsballGeocodeTuple(
        city="Logan",
        state="UT",
        postal="",
        lat=41.748,
        lng=-111.812,
        housenumber="900",
        country="USA",
    ),
    "Holmes Convocation Center, Boone, North Carolina": SportsballGeocodeTuple(
        city="Boone",
        state="NC",
        postal="28608",
        lat=36.210624,
        lng=-81.675952,
        housenumber="111",
        country="USA",
    ),
    "Leede Arena, Hanover, New Hampshire": SportsballGeocodeTuple(
        city="Hanover",
        state="NH",
        postal="03755",
        lat=43.703056,
        lng=-72.283333,
        housenumber="",
        country="USA",
    ),
    "Convocation Center, Ypsilanti, Michigan": SportsballGeocodeTuple(
        city="Ypsilanti",
        state="MI",
        postal="48197",
        lat=42.254444,
        lng=-83.647222,
        housenumber="799",
        country="USA",
    ),
    "Kirby Sports Center, Easton, Pennsylvania": SportsballGeocodeTuple(
        city="Easton",
        state="PA",
        postal="18042",
        lat=40.7019,
        lng=-75.2107,
        housenumber="700",
        country="USA",
    ),
    "Memorial Gymnasium, Orono, Maine": SportsballGeocodeTuple(
        city="Orono",
        state="MA",
        postal="",
        lat=44.9037,
        lng=-68.67,
        housenumber="18",
        country="USA",
    ),
    "Henderson Center, Huntington, West Virginia": SportsballGeocodeTuple(
        city="Huntington",
        state="WV",
        postal="25755",
        lat=38.424517,
        lng=-82.425211,
        housenumber="",
        country="USA",
    ),
    "Costello Athletic Center, Lowell, Massachusetts": SportsballGeocodeTuple(
        city="Lowell",
        state="MA",
        postal="",
        lat=42.6555,
        lng=-71.3242,
        housenumber="",
        country="USA",
    ),
    "Multipurpose Activity Center, West Long Branch, New Jersey": SportsballGeocodeTuple(
        city="West Long Branch",
        state="NJ",
        postal="07764",
        lat=40.279475,
        lng=-74.007583,
        housenumber="400",
        country="USA",
    ),
    "Lundholm Gymnasium, Durham, New Hampshire": SportsballGeocodeTuple(
        city="Durham",
        state="NH",
        postal="03824",
        lat=43.138611,
        lng=-70.938056,
        housenumber="145",
        country="USA",
    ),
    "Petersen Events Center, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="",
        lat=40.443777,
        lng=-79.962274,
        housenumber="3719",
        country="USA",
    ),
    "Dunkin' Donuts Center, Providence, Rhode Island": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="",
        lat=41.823611,
        lng=-71.418333,
        housenumber="1",
        country="USA",
    ),
    "G.B. Hodge Center, Spartanburg, South Carolina": SportsballGeocodeTuple(
        city="Spartanburg",
        state="SC",
        postal="",
        lat=34.996696,
        lng=-81.968774,
        housenumber="",
        country="USA",
    ),
    "Daytona Stadium - Daytona Beach - FL - 32124": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="32124",
        lat=29.173056,
        lng=-81.1175,
        housenumber="3777",
        country="USA",
    ),
    "Redbird Arena, Normal, Illinois": SportsballGeocodeTuple(
        city="Normal",
        state="IL",
        postal="61761",
        lat=40.510606,
        lng=-88.999011,
        housenumber="232",
        country="USA",
    ),
    "Carver-Hawkeye Arena, Iowa City, Iowa": SportsballGeocodeTuple(
        city="Iowa City",
        state="IO",
        postal="52242",
        lat=41.663611,
        lng=-91.554444,
        housenumber="1",
        country="USA",
    ),
    "Baxter Arena, Omaha, Nebraska": SportsballGeocodeTuple(
        city="Omaha",
        state="NB",
        postal="",
        lat=41.236,
        lng=-96.013,
        housenumber="2425",
        country="USA",
    ),
    "Pete Hanna Center, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.4638,
        lng=-86.7973,
        housenumber="",
        country="USA",
    ),
    "The SIU Arena, Carbondale, Illinois": SportsballGeocodeTuple(
        city="Carbondale",
        state="IL",
        postal="",
        lat=37.708333,
        lng=-89.218611,
        housenumber="",
        country="USA",
    ),
    "Moody Coliseum, Dallas, Texas": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="75205",
        lat=32.840278,
        lng=-96.780556,
        housenumber="6024",
        country="USA",
    ),
    "Reed Green Coliseum, Hattiesburg, Mississippi": SportsballGeocodeTuple(
        city="Hattiesburg",
        state="MI",
        postal="",
        lat=31.330833,
        lng=-89.337778,
        housenumber="112",
        country="USA",
    ),
    "Convocation Center, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="78249",
        lat=29.582222,
        lng=-98.621389,
        housenumber="1",
        country="USA",
    ),
    "E.A. Diddle Arena, Bowling Green, Kentucky": SportsballGeocodeTuple(
        city="Bowling Green",
        state="KY",
        postal="42101",
        lat=36.985833,
        lng=-86.4575,
        housenumber="1526",
        country="USA",
    ),
    "Don Haskins Center, El Paso, Texas": SportsballGeocodeTuple(
        city="El Paso",
        state="TX",
        postal="79968",
        lat=31.777608,
        lng=-106.505718,
        housenumber="151",
        country="USA",
    ),
    "Jon M. Huntsman Center, Salt Lake City, Utah": SportsballGeocodeTuple(
        city="Salt Lake City",
        state="UT",
        postal="",
        lat=40.762,
        lng=-111.839,
        housenumber="1825",
        country="USA",
    ),
    "The Pavilion, Davis, California": SportsballGeocodeTuple(
        city="Davis",
        state="CA",
        postal="95616",
        lat=38.541667,
        lng=-121.759444,
        housenumber="1",
        country="USA",
    ),
    "A.G. Spanos Center, Stockton, California": SportsballGeocodeTuple(
        city="Stockton",
        state="CA",
        postal="95211",
        lat=37.976669,
        lng=-121.315095,
        housenumber="1178",
        country="USA",
    ),
    "Leavey Center, Santa Clara, California": SportsballGeocodeTuple(
        city="Santa Clara",
        state="CA",
        postal="95053",
        lat=37.349111,
        lng=-121.935303,
        housenumber="500",
        country="USA",
    ),
    "Mack Sports Complex, Hempstead, New York": SportsballGeocodeTuple(
        city="Hempstead",
        state="NY",
        postal="11549",
        lat=40.719681,
        lng=-73.596865,
        housenumber="245",
        country="USA",
    ),
    "Hulman Center, Terre Haute, Indiana": SportsballGeocodeTuple(
        city="Terre Haute",
        state="IN",
        postal="47809",
        lat=39.468333,
        lng=-87.405,
        housenumber="200",
        country="USA",
    ),
    "Worthen Arena, Muncie, Indiana": SportsballGeocodeTuple(
        city="Muncie",
        state="IN",
        postal="",
        lat=40.206944,
        lng=-85.406111,
        housenumber="1699",
        country="USA",
    ),
    "Chace Athletic Center , Smithfield, Rhode Island": SportsballGeocodeTuple(
        city="Smithfield",
        state="RI",
        postal="",
        lat=41.921008,
        lng=-71.539639,
        housenumber="",
        country="USA",
    ),
    "Littlejohn Coliseum, Clemson, South Carolina": SportsballGeocodeTuple(
        city="Clemson",
        state="SC",
        postal="29631",
        lat=34.680278,
        lng=-82.846389,
        housenumber="",
        country="USA",
    ),
    "Cotterell Court, Hamilton, New York": SportsballGeocodeTuple(
        city="Hamilton",
        state="NY",
        postal="13346",
        lat=42.814957,
        lng=-75.542754,
        housenumber="13",
        country="USA",
    ),
    "Levien Gym, New York, New York": SportsballGeocodeTuple(
        city="New York",
        state="NY",
        postal="",
        lat=40.80979,
        lng=-73.961715,
        housenumber="3030",
        country="USA",
    ),
    "Belk Arena, Davidson, North Carolina": SportsballGeocodeTuple(
        city="Davidson",
        state="NC",
        postal="",
        lat=35.499278,
        lng=-80.840521,
        housenumber="200",
        country="USA",
    ),
    "EagleBank Arena, Fairfax, Virginia": SportsballGeocodeTuple(
        city="Fairfax",
        state="VA",
        postal="",
        lat=38.827,
        lng=-77.31,
        housenumber="4500",
        country="USA",
    ),
    "GSU Convocation Center, Atlanta, Georgia": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30312",
        lat=33.7427,
        lng=-84.38869,
        housenumber="455",
        country="USA",
    ),
    "Lavietes Pavilion, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="02163",
        lat=42.368218,
        lng=-71.125291,
        housenumber="",
        country="USA",
    ),
    "Stabler Arena, Bethlehem, Pennsylvania": SportsballGeocodeTuple(
        city="Bethlehem",
        state="PA",
        postal="18015",
        lat=40.584444,
        lng=-75.356944,
        housenumber="124",
        country="USA",
    ),
    "Prather Coliseum, Natchitoches, Louisiana": SportsballGeocodeTuple(
        city="Natchitoches",
        state="LA",
        postal="71457",
        lat=31.744028,
        lng=-93.095167,
        housenumber="220",
        country="USA",
    ),
    "Ross E.Templeton Center, Clinton, South Carolina": SportsballGeocodeTuple(
        city="Clinton",
        state="SC",
        postal="29325",
        lat=34.465,
        lng=-81.869,
        housenumber="503",
        country="USA",
    ),
    "Kaplan Arena at William and Mary Hall, Williamsburg, Virginia": SportsballGeocodeTuple(
        city="Williamsburg",
        state="VA",
        postal="23186",
        lat=37.273472,
        lng=-76.719625,
        housenumber="751",
        country="USA",
    ),
    "John J. Lee Ampitheater, New Haven, Connecticut": SportsballGeocodeTuple(
        city="New Haven",
        state="CT",
        postal="06511",
        lat=41.313611,
        lng=-72.930556,
        housenumber="70",
        country="USA",
    ),
    "Beeghly Center, Youngstown, Ohio": SportsballGeocodeTuple(
        city="Youngstown",
        state="OH",
        postal="44555",
        lat=41.108056,
        lng=-80.648889,
        housenumber="1",
        country="USA",
    ),
    "Clune Arena , Colorado Springs, Colorado": SportsballGeocodeTuple(
        city="Colorado Springs",
        state="CO",
        postal="",
        lat=39.014,
        lng=-104.8833,
        housenumber="2168",
        country="USA",
    ),
    "Silvio O. Conte Forum, Chestnut Hill, Massachusetts": SportsballGeocodeTuple(
        city="Chestnut Hill",
        state="MA",
        postal="",
        lat=42.335,
        lng=-71.1675,
        housenumber="",
        country="USA",
    ),
    "Millett Hall, Oxford, Ohio": SportsballGeocodeTuple(
        city="Oxford",
        state="OH",
        postal="45056",
        lat=39.517236,
        lng=-84.734544,
        housenumber="500",
        country="USA",
    ),
    "Mizzou Arena, Columbia, Missouri": SportsballGeocodeTuple(
        city="Columbia",
        state="MS",
        postal="65211",
        lat=38.93237,
        lng=-92.33303,
        housenumber="1",
        country="USA",
    ),
    "Johnson Coliseum, Huntsville, Texas": SportsballGeocodeTuple(
        city="Huntsville",
        state="TX",
        postal="77340",
        lat=30.712778,
        lng=-95.546111,
        housenumber="1964",
        country="USA",
    ),
    "Bender Arena, Washington, District of Columbia": SportsballGeocodeTuple(
        city="Washington",
        state="DC",
        postal="",
        lat=38.937778,
        lng=-77.09,
        housenumber="4400",
        country="USA",
    ),
    "Moby Arena, Fort Collins, Colorado": SportsballGeocodeTuple(
        city="Fort Collins",
        state="CO",
        postal="",
        lat=40.575669,
        lng=-105.093403,
        housenumber="951",
        country="USA",
    ),
    "Freedom Hall Civic Center, Johnson City, Tennessee": SportsballGeocodeTuple(
        city="Johnson City",
        state="TN",
        postal="37604",
        lat=36.324444,
        lng=-82.375,
        housenumber="1320",
        country="USA",
    ),
    "McBrayer Arena, Richmond, Kentucky": SportsballGeocodeTuple(
        city="Richmond",
        state="KY",
        postal="40475",
        lat=37.737222,
        lng=-84.301389,
        housenumber="521",
        country="USA",
    ),
    "Hyland Performance Arena, Saint Charles, Missouri": SportsballGeocodeTuple(
        city="Saint Charles",
        state="MO",
        postal="",
        lat=38.78912,
        lng=-90.50352,
        housenumber="",
        country="USA",
    ),
    "CFSB Center, Murray, Kentucky": SportsballGeocodeTuple(
        city="Murray",
        state="KY",
        postal="42071",
        lat=36.62267,
        lng=-88.32031,
        housenumber="1401",
        country="USA",
    ),
    "Echols Memorial Hall, Norfolk, Virginia": SportsballGeocodeTuple(
        city="Norfolk",
        state="VA",
        postal="23504",
        lat=36.847999,
        lng=-76.258157,
        housenumber="700",
        country="USA",
    ),
    "PNC Arena, Raleigh, North Carolina": SportsballGeocodeTuple(
        city="Raleigh",
        state="NC",
        postal="",
        lat=35.803333,
        lng=-78.721944,
        housenumber="1400",
        country="USA",
    ),
    "The Nest, Sacramento, California": SportsballGeocodeTuple(
        city="Sacramento",
        state="CA",
        postal="",
        lat=38.561903,
        lng=-121.426878,
        housenumber="",
        country="USA",
    ),
    "Sam Vadalabene Center , Edwardsville, Illinois": SportsballGeocodeTuple(
        city="Edwardsville",
        state="IL",
        postal="",
        lat=38.795989,
        lng=-89.999883,
        housenumber="35",
        country="USA",
    ),
    "Maples Pavilion, Stanford, California": SportsballGeocodeTuple(
        city="Stanford",
        state="CA",
        postal="",
        lat=37.4296,
        lng=-122.1605,
        housenumber="655",
        country="USA",
    ),
    "Trojan Arena, Troy, Alabama": SportsballGeocodeTuple(
        city="Troy",
        state="AL",
        postal="36082",
        lat=31.802222,
        lng=-85.954722,
        housenumber="5000",
        country="USA",
    ),
    "UCCU Center, Orem, Utah": SportsballGeocodeTuple(
        city="Orem",
        state="UT",
        postal="",
        lat=40.278724,
        lng=-111.716956,
        housenumber="800",
        country="USA",
    ),
    "Western Hall, Macomb, Illinois": SportsballGeocodeTuple(
        city="Macomb",
        state="IL",
        postal="",
        lat=40.471589,
        lng=-90.685201,
        housenumber="",
        country="USA",
    ),
    "Allen Arena, Nashville, Tennessee": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.103833,
        lng=-86.798836,
        housenumber="1",
        country="USA",
    ),
    "The Legacy Center, Lake Charles, Louisiana": SportsballGeocodeTuple(
        city="Lake Charles",
        state="LA",
        postal="70607",
        lat=30.1755,
        lng=-93.2095,
        housenumber="",
        country="USA",
    ),
    "Watsco Center, Coral Gables, Florida": SportsballGeocodeTuple(
        city="Coral Gables",
        state="FL",
        postal="",
        lat=25.715,
        lng=-80.279167,
        housenumber="1245",
        country="USA",
    ),
    "Peter W. Stott Center, Portland, Oregon": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="97201",
        lat=45.510987,
        lng=-122.687471,
        housenumber="930",
        country="USA",
    ),
    "Haas Pavilion, Berkeley, California": SportsballGeocodeTuple(
        city="Berkeley",
        state="CA",
        postal="",
        lat=37.8694,
        lng=-122.262,
        housenumber="14",
        country="USA",
    ),
    "Murphy Athletic Center, Murfreesboro, Tennessee": SportsballGeocodeTuple(
        city="Murfreesboro",
        state="TN",
        postal="37132",
        lat=35.852467,
        lng=-86.369803,
        housenumber="2650",
        country="USA",
    ),
    "Adams Center/Dahlberg Arena, Missoula, Montana": SportsballGeocodeTuple(
        city="Missoula",
        state="MT",
        postal="",
        lat=46.864,
        lng=-113.983,
        housenumber="32",
        country="USA",
    ),
    "Kiefer Lakefront Arena, New Orleans , Louisiana": SportsballGeocodeTuple(
        city="New Orleans",
        state="LA",
        postal="",
        lat=30.03,
        lng=-90.050556,
        housenumber="6801",
        country="USA",
    ),
    "Bank of Kentucky Center, Highland Heights, Kentucky": SportsballGeocodeTuple(
        city="Highland Heights",
        state="KY",
        postal="41099",
        lat=39.032273,
        lng=-84.458864,
        housenumber="500",
        country="USA",
    ),
    "Robins Center, Richmond, Virginia": SportsballGeocodeTuple(
        city="Richmond",
        state="VA",
        postal="23173",
        lat=37.580701,
        lng=-77.538987,
        housenumber="",
        country="USA",
    ),
    "Allen County War Memorial Coliseum, Fort Wayne, Indiana": SportsballGeocodeTuple(
        city="Fort Wayne",
        state="IN",
        postal="23173",
        lat=41.115556,
        lng=-85.124444,
        housenumber="4000",
        country="USA",
    ),
    "Island Federal Credit Union, Stony Brook, New York": SportsballGeocodeTuple(
        city="Stony Brook",
        state="NY",
        postal="11790",
        lat=40.91741,
        lng=-73.125955,
        housenumber="100",
        country="USA",
    ),
    "Cajundome, Lafayette, Louisiana": SportsballGeocodeTuple(
        city="Lafayette",
        state="LA",
        postal="70506",
        lat=30.218444,
        lng=-92.039056,
        housenumber="444",
        country="USA",
    ),
    "Thomas Assembly Center, Ruston, Louisiana": SportsballGeocodeTuple(
        city="Ruston",
        state="LA",
        postal="71272",
        lat=32.5321,
        lng=-92.6584,
        housenumber="1650",
        country="USA",
    ),
    "Worthington Arena, Bozeman, Montana": SportsballGeocodeTuple(
        city="Bozeman",
        state="MT",
        postal="",
        lat=45.6633,
        lng=-111.0506,
        housenumber="1",
        country="USA",
    ),
    "Mabee Center, Tulsa, Oklahoma": SportsballGeocodeTuple(
        city="Tulsa",
        state="OK",
        postal="74171",
        lat=36.04789,
        lng=-95.95573,
        housenumber="7777",
        country="USA",
    ),
    "Centrum, Cedar City, Utah": SportsballGeocodeTuple(
        city="Cedar City",
        state="UT",
        postal="84720",
        lat=37.675556,
        lng=-113.073056,
        housenumber="351",
        country="USA",
    ),
    "Schoenecker Arena, St. Paul, Minnesota": SportsballGeocodeTuple(
        city="St. Paul",
        state="MN",
        postal="",
        lat=44.9395,
        lng=-93.1945,
        housenumber="",
        country="USA",
    ),
    "Icardo Center, Bakersfield, California": SportsballGeocodeTuple(
        city="Bakersfield",
        state="CA",
        postal="",
        lat=35.3475,
        lng=-119.102778,
        housenumber="",
        country="USA",
    ),
    "Titan Gym, Fullerton, California": SportsballGeocodeTuple(
        city="Fullerton",
        state="CA",
        postal="92834",
        lat=33.883046,
        lng=-117.88609,
        housenumber="800",
        country="USA",
    ),
    "Burns Arena, St. George, Utah": SportsballGeocodeTuple(
        city="St. George",
        state="UT",
        postal="",
        lat=37.101,
        lng=-113.566,
        housenumber="400",
        country="USA",
    ),
    "RIMAC Arena, La Jolla, California": SportsballGeocodeTuple(
        city="La Jolla",
        state="CA",
        postal="",
        lat=32.885278,
        lng=-117.239223,
        housenumber="9860",
        country="USA",
    ),
    "Climate Pledge Arena, Seattle, Washington": SportsballGeocodeTuple(
        city="Seattle",
        state="WA",
        postal="",
        lat=47.622,
        lng=-122.354,
        housenumber="334",
        country="USA",
    ),
    "Draddy Gymnasium, Riverdale, New York": SportsballGeocodeTuple(
        city="Riverdale",
        state="NY",
        postal="",
        lat=40.89073,
        lng=-73.900158,
        housenumber="",
        country="USA",
    ),
    "William H. Pitt Center, Fairfield, Connecticut": SportsballGeocodeTuple(
        city="Fairfield",
        state="CT",
        postal="06825",
        lat=41.219439,
        lng=-73.244628,
        housenumber="5151",
        country="USA",
    ),
    "Alumni Arena, Buffalo, New York": SportsballGeocodeTuple(
        city="Buffalo",
        state="NY",
        postal="14221",
        lat=43.0,
        lng=-78.781111,
        housenumber="175",
        country="USA",
    ),
    "Merkert Gymnasium, Easton, Massachusetts": SportsballGeocodeTuple(
        city="Easton",
        state="MA",
        postal="",
        lat=42.0576,
        lng=-71.0789,
        housenumber="",
        country="USA",
    ),
    "John F. Savage Hall, Toledo, Ohio": SportsballGeocodeTuple(
        city="Toledo",
        state="OH",
        postal="43606",
        lat=41.660232,
        lng=-83.609795,
        housenumber="2025",
        country="USA",
    ),
    "War Memorial at The Sobrato Center, San Francisco, California": SportsballGeocodeTuple(
        city="San Francisco",
        state="CA",
        postal="94118",
        lat=37.776944,
        lng=-122.449444,
        housenumber="2335",
        country="USA",
    ),
    "The Jungle, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="46202",
        lat=39.770556,
        lng=-86.175,
        housenumber="901",
        country="USA",
    ),
    "Lantz Arena, Charleston, Illinois": SportsballGeocodeTuple(
        city="Charleston",
        state="IL",
        postal="61920",
        lat=39.480403,
        lng=-88.178844,
        housenumber="250",
        country="USA",
    ),
    "Friel Court at Beasley Coliseum, Pullman, Washington": SportsballGeocodeTuple(
        city="Pullman",
        state="WA",
        postal="",
        lat=46.735,
        lng=-117.1575,
        housenumber="925",
        country="USA",
    ),
    "The Matadome, Northridge, California": SportsballGeocodeTuple(
        city="Northridge",
        state="CA",
        postal="91330",
        lat=34.241974,
        lng=-118.526484,
        housenumber="18111",
        country="USA",
    ),
    "UC Riverside Student Recreation Center, Riverside, California": SportsballGeocodeTuple(
        city="Riverside",
        state="CA",
        postal="",
        lat=33.9789,
        lng=-117.32813,
        housenumber="",
        country="USA",
    ),
    "Finneran Pavilion, Villanova, Pennsylvania": SportsballGeocodeTuple(
        city="Villanova",
        state="PA",
        postal="19085",
        lat=40.034072,
        lng=-75.336553,
        housenumber="",
        country="USA",
    ),
    "Allen Fieldhouse, Lawrence, Kansas": SportsballGeocodeTuple(
        city="Lawrence",
        state="KS",
        postal="",
        lat=38.954306,
        lng=-95.252394,
        housenumber="1651",
        country="USA",
    ),
    "CFE Arena, Orlando, Florida": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="",
        lat=28.6068,
        lng=-81.1976,
        housenumber="12777",
        country="USA",
    ),
    "Dale F. Halton Arena, Charlotte, North Carolina": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="28223",
        lat=35.306111,
        lng=-80.734444,
        housenumber="9201",
        country="USA",
    ),
    "A.J. Palumbo Center, Pittsburgh, Pennsylvania": SportsballGeocodeTuple(
        city="Pittsburgh",
        state="PA",
        postal="15282",
        lat=40.4374,
        lng=-79.9879,
        housenumber="600",
        country="USA",
    ),
    "Thomas M. Ryan Center, Kingston, Rhode Island": SportsballGeocodeTuple(
        city="Kingston",
        state="RI",
        postal="02881",
        lat=41.4875,
        lng=-71.535556,
        housenumber="1",
        country="USA",
    ),
    "Prudential Center, Newark, New Jersey": SportsballGeocodeTuple(
        city="Newark",
        state="NJ",
        postal="",
        lat=40.733611,
        lng=-74.171111,
        housenumber="25",
        country="USA",
    ),
    "Ford Center, Evansville, Indiana": SportsballGeocodeTuple(
        city="Evansville",
        state="IN",
        postal="",
        lat=37.972189,
        lng=-87.567844,
        housenumber="1",
        country="USA",
    ),
    "Super Pit, Denton, Texas": SportsballGeocodeTuple(
        city="Denton",
        state="TX",
        postal="76201",
        lat=33.208333,
        lng=-97.153889,
        housenumber="801",
        country="USA",
    ),
    "Athletics-Recreation Center, Valparaiso, Indiana": SportsballGeocodeTuple(
        city="Valparaiso",
        state="IN",
        postal="46383",
        lat=41.464198,
        lng=-87.048338,
        housenumber="1009",
        country="USA",
    ),
    "CSU Fieldhouse, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29406",
        lat=32.980822,
        lng=-80.067125,
        housenumber="9200",
        country="USA",
    ),
    "Hart Recreation Center, Worcester, Massachusetts": SportsballGeocodeTuple(
        city="Worcester",
        state="MA",
        postal="01610",
        lat=42.235046,
        lng=-71.806381,
        housenumber="1",
        country="USA",
    ),
    "McAlister Field House, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29409",
        lat=32.798508,
        lng=-79.962573,
        housenumber="171",
        country="USA",
    ),
    "Paul Porter Arena, Boiling Springs, North Carolina": SportsballGeocodeTuple(
        city="Boiling Springs",
        state="NC",
        postal="",
        lat=35.246538,
        lng=-81.669518,
        housenumber="",
        country="USA",
    ),
    "Mullins Center, Amherst, Massachusetts": SportsballGeocodeTuple(
        city="Amherst",
        state="MA",
        postal="01003",
        lat=42.389381,
        lng=-72.533439,
        housenumber="200",
        country="USA",
    ),
    "Richardson Indoor Stadium, Spartanburg, South Carolina": SportsballGeocodeTuple(
        city="Spartanburg",
        state="SC",
        postal="29303",
        lat=34.963427,
        lng=-81.93363,
        housenumber="601",
        country="USA",
    ),
    "Chaifetz Arena, St. Louis, Missouri": SportsballGeocodeTuple(
        city="St. Louis",
        state="MO",
        postal="63103",
        lat=38.63246,
        lng=-90.22797,
        housenumber="1",
        country="USA",
    ),
    "Fiserv Forum, Milwaukee, Wisconsin": FISERV_FORUM,
    "WVU Coliseum, Morgantown, West Virginia": SportsballGeocodeTuple(
        city="Morgantown",
        state="WV",
        postal="26505",
        lat=39.649167,
        lng=-79.981111,
        housenumber="",
        country="USA",
    ),
    "Bartow Arena, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.502164,
        lng=-86.809244,
        housenumber="617",
        country="USA",
    ),
    "McKeon Pavilion, Moraga, California": SportsballGeocodeTuple(
        city="Moraga",
        state="CA",
        postal="",
        lat=37.841247,
        lng=-122.106409,
        housenumber="1928",
        country="USA",
    ),
    "KFC Yum! Center, Louisville, Kentucky": SportsballGeocodeTuple(
        city="Louisville",
        state="KY",
        postal="",
        lat=38.2575,
        lng=-85.753889,
        housenumber="1",
        country="USA",
    ),
    "DiSanto Field - Cleveland - OH - 44106": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="44106",
        lat=41.513444,
        lng=-81.603639,
        housenumber="1747",
        country="USA",
    ),
    "University Arena, Kalamazoo, Michigan": SportsballGeocodeTuple(
        city="Kalamazoo",
        state="MI",
        postal="",
        lat=42.283372,
        lng=-85.60845,
        housenumber="",
        country="USA",
    ),
    "Gallagher-Iba Arena, Stillwater, Oklahoma": SportsballGeocodeTuple(
        city="Stillwater",
        state="OK",
        postal="74078",
        lat=36.125833,
        lng=-97.065,
        housenumber="1046",
        country="USA",
    ),
    "Arena-Auditorium, Laramie, Wyoming": SportsballGeocodeTuple(
        city="Laramie",
        state="WY",
        postal="82071",
        lat=41.313344,
        lng=-105.569419,
        housenumber="1000",
        country="USA",
    ),
    "DunnâOliver Acadome, Montgomery, Alabama": DUNN_OLIVER_ACADOME,
    "Health & Physical Education Arena, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="",
        lat=29.43,
        lng=-95.21,
        housenumber="",
        country="USA",
    ),
    "Memorial Hall, Dover, Delaware": SportsballGeocodeTuple(
        city="Dover",
        state="DE",
        postal="",
        lat=39.1876,
        lng=-75.5434,
        housenumber="",
        country="USA",
    ),
    "Franklin Field - Philadelphia - PA - 19104": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19104",
        lat=39.95,
        lng=-75.19,
        housenumber="",
        country="USA",
    ),
    "Texas A&MâCommerce Field House, Commerce, Texas": TEXAS_AM_COMMERCE_FIELD_HOUSE,
    "William J. Nicks Building, Prairie View, Texas": SportsballGeocodeTuple(
        city="Prairie View",
        state="TX",
        postal="77446",
        lat=30.092278,
        lng=-95.993083,
        housenumber="100",
        country="USA",
    ),
    "Matthew Knight Arena, Eugene, Oregon": SportsballGeocodeTuple(
        city="Eugene",
        state="OR",
        postal="97401",
        lat=44.045,
        lng=-123.066,
        housenumber="1390",
        country="USA",
    ),
    "Harry A. Gampel Pavilion, Storrs, Connecticut": SportsballGeocodeTuple(
        city="Storrs",
        state="CT",
        postal="06269",
        lat=41.805292,
        lng=-72.254194,
        housenumber="2095",
        country="USA",
    ),
    "Steinberg Wellness Center, Brooklyn, New York": SportsballGeocodeTuple(
        city="Brooklyn",
        state="NY",
        postal="",
        lat=40.69059,
        lng=-73.979176,
        housenumber="",
        country="USA",
    ),
    "The Palestra, Philadelphia, Pennsylvania": SportsballGeocodeTuple(
        city="Philadelphia",
        state="PA",
        postal="19104",
        lat=39.951411,
        lng=-75.188606,
        housenumber="235",
        country="USA",
    ),
    "Spiro Sports Center, Staten Island, New York": SportsballGeocodeTuple(
        city="Staten Island",
        state="NY",
        postal="10301",
        lat=40.614966,
        lng=-74.095729,
        housenumber="",
        country="USA",
    ),
    "Pizzitola Sports Center, Providence, Rhode Island": SportsballGeocodeTuple(
        city="Providence",
        state="RI",
        postal="02906",
        lat=41.831743,
        lng=-71.398043,
        housenumber="",
        country="USA",
    ),
    "Newman Arena, Ithaca, New York": SportsballGeocodeTuple(
        city="Ithaca",
        state="NY",
        postal="14853",
        lat=42.445794,
        lng=-76.476581,
        housenumber="",
        country="USA",
    ),
    "Al Lawson Center, Tallahassee, Florida": SportsballGeocodeTuple(
        city="Tallahassee",
        state="FL",
        postal="32310",
        lat=30.424318,
        lng=-84.290473,
        housenumber="1800",
        country="USA",
    ),
    "Hanner Fieldhouse, Statesboro, Georgia": SportsballGeocodeTuple(
        city="Statesboro",
        state="GA",
        postal="30458",
        lat=32.427778,
        lng=-81.779444,
        housenumber="590",
        country="USA",
    ),
    "Carnesecca Arena, Jamaica, New York": SportsballGeocodeTuple(
        city="Jamaica",
        state="NY",
        postal="",
        lat=40.724167,
        lng=-73.794444,
        housenumber="",
        country="USA",
    ),
    "Pan American Center, Las Cruces, New Mexico": SportsballGeocodeTuple(
        city="Las Cruces",
        state="NM",
        postal="88003",
        lat=32.284,
        lng=-106.7422,
        housenumber="1810",
        country="USA",
    ),
    "Jadwin Gymnasium, Princeton, New Jersey": SportsballGeocodeTuple(
        city="Princeton",
        state="NJ",
        postal="08542",
        lat=40.343449,
        lng=-74.648595,
        housenumber="",
        country="USA",
    ),
    "Matthews Arena, Boston, Massachusetts": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="",
        lat=42.341111,
        lng=-71.084444,
        housenumber="238",
        country="USA",
    ),
    "Calihan Hall, Detroit, Michigan": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="48221",
        lat=42.414167,
        lng=-83.135833,
        housenumber="4001",
        country="USA",
    ),
    "Curry Arena, Charlotte, North Carolina": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="28274",
        lat=35.1884989,
        lng=-80.8351236,
        housenumber="2201",
        country="USA",
    ),
    "Events Center, Binghamton, New York": SportsballGeocodeTuple(
        city="Binghamton",
        state="NY",
        postal="13902-6000",
        lat=42.093333,
        lng=-75.971944,
        housenumber="4400",
        country="USA",
    ),
    "Jeff Farris Center, Conway, Arkansas": SportsballGeocodeTuple(
        city="Conway",
        state="AR",
        postal="",
        lat=35.081667,
        lng=-92.459444,
        housenumber="",
        country="USA",
    ),
    "TD Arena, Charleston, South Carolina": SportsballGeocodeTuple(
        city="Charleston",
        state="SC",
        postal="29401",
        lat=32.785556,
        lng=-79.934444,
        housenumber="301",
        country="USA",
    ),
    "Betty Engelstad Sioux Center , Grand Forks, North Dakota": SportsballGeocodeTuple(
        city="Grand Forks",
        state="ND",
        postal="58203",
        lat=47.92767,
        lng=-97.07247,
        housenumber="1",
        country="USA",
    ),
    "Reese Court, Cheney, Washington": SportsballGeocodeTuple(
        city="Cheney",
        state="WA",
        postal="",
        lat=47.4914,
        lng=-117.5892,
        housenumber="",
        country="USA",
    ),
    "ICCU Arena, Moscow, Idaho": SportsballGeocodeTuple(
        city="Moscow",
        state="ID",
        postal="",
        lat=46.7275,
        lng=-117.018056,
        housenumber="",
        country="USA",
    ),
    "Flowers Hall, Florence, Alabama": SportsballGeocodeTuple(
        city="Florence",
        state="AL",
        postal="",
        lat=34.808333,
        lng=-87.683889,
        housenumber="615",
        country="USA",
    ),
    "CBU Events Center, Riverside, California": SportsballGeocodeTuple(
        city="Riverside",
        state="CA",
        postal="",
        lat=33.927501,
        lng=-117.423266,
        housenumber="8431",
        country="USA",
    ),
    "Spokane Veterans Memorial Arena, Spokane, Washington": SportsballGeocodeTuple(
        city="Spokane",
        state="WA",
        postal="",
        lat=47.666,
        lng=-117.423,
        housenumber="720",
        country="USA",
    ),
    "Indiana Farmers Coliseum, Indianapolis, Indiana": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="",
        lat=39.8275,
        lng=-86.135,
        housenumber="1202",
        country="USA",
    ),
    "Moody Coliseum , Abilene, Texas": SportsballGeocodeTuple(
        city="Abilene",
        state="TX",
        postal="",
        lat=32.470333,
        lng=-99.70925,
        housenumber="",
        country="USA",
    ),
    "Cross Insurance Center, Bangor, Maine": SportsballGeocodeTuple(
        city="Bangor",
        state="MA",
        postal="",
        lat=44.7893,
        lng=-68.7787,
        housenumber="515",
        country="USA",
    ),
    "Klotsche Center, Milwaukee, Wisconsin": SportsballGeocodeTuple(
        city="Milwaukee",
        state="WI",
        postal="53233",
        lat=43.079414,
        lng=-87.879783,
        housenumber="3409",
        country="USA",
    ),
    "Dugan Wellness Center, Corpus Christi, Texas": SportsballGeocodeTuple(
        city="Corpus Christi",
        state="TX",
        postal="78412",
        lat=27.711472,
        lng=-97.324361,
        housenumber="6300",
        country="USA",
    ),
    "Fleming Gymnasium, Greensboro, North Carolina": SportsballGeocodeTuple(
        city="Greensboro",
        state="NC",
        postal="",
        lat=36.069384,
        lng=-79.81268,
        housenumber="",
        country="USA",
    ),
    "Enterprise Center, St. Louis, Missouri": SportsballGeocodeTuple(
        city="St. Louis",
        state="MO",
        postal="",
        lat=38.626667,
        lng=-90.2025,
        housenumber="1401",
        country="USA",
    ),
    "Legacy Arena, Birmingham, Alabama": SportsballGeocodeTuple(
        city="Birmingham",
        state="AL",
        postal="",
        lat=33.52378,
        lng=-86.812935,
        housenumber="2100",
        country="USA",
    ),
    "MassMutual Center, Springfield, Massachusetts": SportsballGeocodeTuple(
        city="Springfield",
        state="MA",
        postal="",
        lat=42.102222,
        lng=-72.586944,
        housenumber="1277",
        country="USA",
    ),
    "Sanford Pentagon, Sioux Falls, South Dakota": SportsballGeocodeTuple(
        city="Sioux Falls",
        state="SD",
        postal="",
        lat=43.593056,
        lng=-96.758611,
        housenumber="2210",
        country="USA",
    ),
    "Barclays Center, Brooklyn, New York": SportsballGeocodeTuple(
        city="Brooklyn",
        state="NY",
        postal="",
        lat=40.682661,
        lng=-73.975225,
        housenumber="620",
        country="USA",
    ),
    "Orleans Arena, Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.105833,
        lng=-115.202222,
        housenumber="4500",
        country="USA",
    ),
    "Mohegan Sun Arena, Uncasville, Connecticut": SportsballGeocodeTuple(
        city="Uncasville",
        state="CT",
        postal="",
        lat=41.491111,
        lng=-72.089722,
        housenumber="1",
        country="USA",
    ),
    "Hilliard Gates Sports Center, Fort Wayne, Indiana": SportsballGeocodeTuple(
        city="Fort Wayne",
        state="IN",
        postal="46835",
        lat=41.119,
        lng=-85.1076,
        housenumber="2101",
        country="USA",
    ),
    "XL Center, Hartford, Connecticut": SportsballGeocodeTuple(
        city="Hartford",
        state="CT",
        postal="",
        lat=41.768333,
        lng=-72.676944,
        housenumber="1",
        country="USA",
    ),
    "Spectrum Center, Charlotte, North Carolina": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="",
        lat=35.225,
        lng=-80.839167,
        housenumber="333",
        country="USA",
    ),
    "Little Caesars Arena, Detroit, Michigan": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="",
        lat=42.341111,
        lng=-83.055,
        housenumber="2645",
        country="USA",
    ),
    "Sprint Center, Kansas City, Missouri": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="",
        lat=39.0975,
        lng=-94.580278,
        housenumber="1407",
        country="USA",
    ),
    "Mississippi Coliseum, Jackson, Mississippi": SportsballGeocodeTuple(
        city="Jackson",
        state="MS",
        postal="",
        lat=32.300126,
        lng=-90.172121,
        housenumber="1207",
        country="USA",
    ),
    "Hytche Athletic Center, Princess Anne, Maryland": SportsballGeocodeTuple(
        city="Princess Anne",
        state="MD",
        postal="",
        lat=38.211184,
        lng=-75.687227,
        housenumber="",
        country="USA",
    ),
    "State Farm Arena, Atlanta, Georgia": STATE_FARM_ARENA,
    "Gainbridge Fieldhouse, Indianapolis, Indiana": GAINBRIDGE_FIELDHOUSE,
    "Mississippi Coast Coliseum, Biloxi, Mississippi": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="39531",
        lat=30.3935,
        lng=-88.9746,
        housenumber="2350",
        country="USA",
    ),
    "Footprint Center, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "Simmons Bank Arena, North Little Rock, Arkansas": SportsballGeocodeTuple(
        city="North Little Rock",
        state="AR",
        postal="72114",
        lat=34.755111,
        lng=-92.264439,
        housenumber="1",
        country="USA",
    ),
    "FLA Live Arena, Sunrise, Florida": SportsballGeocodeTuple(
        city="Sunrise",
        state="FL",
        postal="",
        lat=26.158333,
        lng=-80.325556,
        housenumber="1",
        country="USA",
    ),
    "Dollar Loan Center, Henderson, Nevada": SportsballGeocodeTuple(
        city="Henderson",
        state="NV",
        postal="",
        lat=36.018977,
        lng=-115.081632,
        housenumber="200",
        country="USA",
    ),
    "Vivint Arena, Salt Lake City, Utah": VIVINT_ARENA,
    "Rock Hill Sports & Event Center, Rock Hill, South Carolina": SportsballGeocodeTuple(
        city="Rock Hill",
        state="SC",
        postal="29730",
        lat=34.9318802,
        lng=-81.0299645,
        housenumber="326",
        country="USA",
    ),
    "David Stopher Gymnasium, Thibodaux, Louisiana": SportsballGeocodeTuple(
        city="Thibodaux",
        state="LA",
        postal="",
        lat=29.79235,
        lng=-90.80135,
        housenumber="",
        country="USA",
    ),
    "Dickies Arena, Fort Worth, Texas": SportsballGeocodeTuple(
        city="Fort Worth",
        state="TX",
        postal="",
        lat=32.740891,
        lng=-97.369938,
        housenumber="1911",
        country="USA",
    ),
    "Rolle Activity Center, Flagstaff, Arizona": SportsballGeocodeTuple(
        city="Flagstaff",
        state="AZ",
        postal="86001",
        lat=35.1768307,
        lng=-111.6553593,
        housenumber="",
        country="USA",
    ),
    "Idaho Central Arena, Boise, Idaho": SportsballGeocodeTuple(
        city="Boise",
        state="ID",
        postal="",
        lat=43.614,
        lng=-116.204,
        housenumber="233",
        country="USA",
    ),
    "Wellness Center, Brooklyn, New York": SportsballGeocodeTuple(
        city="Brooklyn",
        state="NY",
        postal="",
        lat=40.69059,
        lng=-73.979176,
        housenumber="",
        country="USA",
    ),
    "Baha Mar Convention Center, Nassau": SportsballGeocodeTuple(
        city="Nassau",
        state="",
        postal="",
        lat=25.0703613,
        lng=-77.4001874,
        housenumber="",
        country="Bahamas",
    ),
    "DeGol Arena, Loretto, Pennsylvania": SportsballGeocodeTuple(
        city="Loretto",
        state="PA",
        postal="15940",
        lat=40.504612,
        lng=-78.640901,
        housenumber="140",
        country="USA",
    ),
    "MGM Grand Garden Arena, Paradise, Nevada": SportsballGeocodeTuple(
        city="Paradise",
        state="NV",
        postal="",
        lat=36.104808,
        lng=-115.168614,
        housenumber="3799",
        country="USA",
    ),
    "Imperial Arena at Atlantis Resort, Nassau": SportsballGeocodeTuple(
        city="Nassau",
        state="",
        postal="",
        lat=25.0836,
        lng=-77.318,
        housenumber="1",
        country="Bahamas",
    ),
    "State Farm Field House, Lake Buena Vista, Florida": SportsballGeocodeTuple(
        city="Lake Buena Vista",
        state="FL",
        postal="",
        lat=28.337083,
        lng=-81.556,
        housenumber="",
        country="USA",
    ),
    "Los Angeles Memorial Sports Arena": LOS_ANGELES_MEMORIAL_COLESIUM,
    "Boston Garden": SportsballGeocodeTuple(
        city="Boston",
        state="MA",
        postal="",
        lat=42.365833,
        lng=-71.061667,
        housenumber="150",
        country="USA",
    ),
    "Cow Palace - Daly City, California - United States": SportsballGeocodeTuple(
        city="Daly City",
        state="CA",
        postal="",
        lat=37.706667,
        lng=-122.418611,
        housenumber="2600",
        country="USA",
    ),
    "The Forum": THE_FORUM,
    "Spectrum": SPECTRUM,
    "Madison Square Garden - New York City, New York - United States": MADISON_SQUARE_GARDEN,
    "Milwaukee Arena": MILWAUKEE_ARENA,
    "Chicago Stadium": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="",
        lat=41.881667,
        lng=-87.672778,
        housenumber="1800",
        country="USA",
    ),
    "Memorial Coliseum - Portland, Oregon - United States": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="",
        lat=45.532,
        lng=-122.669,
        housenumber="300",
        country="USA",
    ),
    "McNichols Sports Arena": SportsballGeocodeTuple(
        city="Denver",
        state="CO",
        postal="",
        lat=39.742778,
        lng=-105.0225,
        housenumber="1635",
        country="USA",
    ),
    "Kemper Arena": SportsballGeocodeTuple(
        city="Kansas City",
        state="MO",
        postal="",
        lat=39.742778,
        lng=-105.0225,
        housenumber="1800",
        country="USA",
    ),
    "Omni Coliseum": SportsballGeocodeTuple(
        city="Atlanta",
        state="GA",
        postal="30303",
        lat=33.7575,
        lng=-84.396667,
        housenumber="100",
        country="USA",
    ),
    "Great Western Forum": THE_FORUM,
    "The Palace of Auburn Hills - Auburn Hills, MI - USA": SportsballGeocodeTuple(
        city="Auburn Hills",
        state="MI",
        postal="",
        lat=42.696944,
        lng=-83.245556,
        housenumber="6",
        country="USA",
    ),
    "America West Arena": AMERICA_WEST_ARENA,
    "Quicken Loans Arena - Cleveland, Ohio - United States": QUICKEN_LOANS_ARENA,
    "Pepsi Center - Denver, Colorado, U.S. - United States": PEPSI_CENTRE,
    "Staples Center": STAPLES_CENTRE,
    "American Airlines Arena": AMERICAN_AIRLINES_ARENA,
    "Chesapeake Energy Arena - Oklahoma City, Oklahoma - United States": CHESAPEAKE_ENERGY_ARENA,
    "AT&T Center - San Antonio, Texas - United States": ATT_CENTER,
    "Oakland Arena - Oakland, California - United States": OAKLAND_ARENA,
    "ESPN Wide World of Sports Complex": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "International Amphitheatre": SportsballGeocodeTuple(
        city="Chicago",
        state="IL",
        postal="60609",
        lat=41.816111,
        lng=-87.646111,
        housenumber="4220",
        country="USA",
    ),
    "Lahaina Civic Center, Lahaina, Hawaii": SportsballGeocodeTuple(
        city="Lahaina",
        state="HI",
        postal="",
        lat=20.904995,
        lng=-156.683852,
        housenumber="1840",
        country="USA",
    ),
    "San Jose Civic Auditorium": SportsballGeocodeTuple(
        city="San Jose",
        state="CA",
        postal="95113",
        lat=37.330987,
        lng=-121.890168,
        housenumber="135",
        country="USA",
    ),
    "Suncoast Credit Union Arena, Fort Myers, Florida": SportsballGeocodeTuple(
        city="Fort Myers",
        state="FL",
        postal="33919",
        lat=26.5478,
        lng=-81.8869,
        housenumber="13351",
        country="USA",
    ),
    "The Spectrum - Guildford, Surrey, United Kingdom - United Kingdom": SportsballGeocodeTuple(
        city="Surrey",
        state="",
        postal="",
        lat=51.24844,
        lng=-0.56288,
        housenumber="",
        country="UK",
    ),
    "San Diego Sports Arena": SportsballGeocodeTuple(
        city="San Diego",
        state="CA",
        postal="",
        lat=32.755278,
        lng=-117.212222,
        housenumber="3500",
        country="USA",
    ),
    "Hertz Arena, Estero, Florida": SportsballGeocodeTuple(
        city="Estero",
        state="FL",
        postal="",
        lat=26.440668,
        lng=-81.778809,
        housenumber="11000",
        country="USA",
    ),
    "Hard Rock Hotel Riviera Maya, Cancun": SportsballGeocodeTuple(
        city="Cancun",
        state="",
        postal="",
        lat=20.5069801,
        lng=-87.215373,
        housenumber="",
        country="Mexico",
    ),
    "T-Mobile Arena, Las Vegas, Nevada": SportsballGeocodeTuple(
        city="Las Vegas",
        state="NV",
        postal="",
        lat=36.102778,
        lng=-115.178333,
        housenumber="3780",
        country="USA",
    ),
    "Ocean Center, Daytona Beach, Florida": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="",
        lat=29.2287,
        lng=-81.0106,
        housenumber="101",
        country="USA",
    ),
    "John Gray Gymnasium, Grand Cayman": SportsballGeocodeTuple(
        city="Grand Cayman",
        state="",
        postal="",
        lat=19.279316,
        lng=-81.385651,
        housenumber="73",
        country="UK",
    ),
    "Woodling Gym, Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.503355,
        lng=-81.671269,
        housenumber="",
        country="USA",
    ),
    "Municipal Auditorium": SportsballGeocodeTuple(
        city="Nashville",
        state="TN",
        postal="",
        lat=36.167581,
        lng=-86.782244,
        housenumber="417",
        country="USA",
    ),
    "Elridge Wilburn Blake Sports and Fitness Center, St. Thomas": SportsballGeocodeTuple(
        city="St. Thomas",
        state="USVI",
        postal="",
        lat=18.340096,
        lng=-64.97306,
        housenumber="",
        country="USA",
    ),
    "Market Square Arena": SportsballGeocodeTuple(
        city="Indianapolis",
        state="IN",
        postal="46204",
        lat=39.768333,
        lng=-86.151944,
        housenumber="300",
        country="USA",
    ),
    "Chase Center, San Francisco, California": SportsballGeocodeTuple(
        city="San Francisco",
        state="CA",
        postal="",
        lat=37.768056,
        lng=-122.3875,
        housenumber="1",
        country="USA",
    ),
    "Reunion Arena": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="75207",
        lat=32.772778,
        lng=-96.808056,
        housenumber="777",
        country="USA",
    ),
    "Walsh Gymnasium, South Orange, New Jersey": SportsballGeocodeTuple(
        city="South Orange",
        state="NJ",
        postal="07079",
        lat=40.74169,
        lng=-74.244921,
        housenumber="",
        country="USA",
    ),
    "Alamodome, San Antonio, Texas": ALAMODOME,
    "Moore Gymnasium, Daytona Beach, Florida": SportsballGeocodeTuple(
        city="Daytona Beach",
        state="FL",
        postal="",
        lat=29.210895,
        lng=-81.030977,
        housenumber="",
        country="USA",
    ),
    "Tacoma Dome": SportsballGeocodeTuple(
        city="Tacoma",
        state="WA",
        postal="98421",
        lat=47.236667,
        lng=-122.426667,
        housenumber="2727",
        country="USA",
    ),
    "Royal Farms Arena, Baltimore, Maryland": SportsballGeocodeTuple(
        city="Baltimore",
        state="MD",
        postal="",
        lat=39.288611,
        lng=-76.618889,
        housenumber="201",
        country="USA",
    ),
    "Joe Louis Arena - Detroit, Michigan - United States": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="",
        lat=42.325278,
        lng=-83.051389,
        housenumber="19",
        country="USA",
    ),
    "Arco Arena - Sacramento, California - United States": SportsballGeocodeTuple(
        city="Sacramento",
        state="CA",
        postal="",
        lat=38.649167,
        lng=-121.518056,
        housenumber="1",
        country="USA",
    ),
    "Nassau Coliseum, Uniondale, New York": SportsballGeocodeTuple(
        city="Uniondale",
        state="NY",
        postal="",
        lat=40.722778,
        lng=-73.590556,
        housenumber="1255",
        country="USA",
    ),
    "Bradley Center": BRADLEY_CENTER,
    "Charlotte Coliseum": SportsballGeocodeTuple(
        city="Charlotte",
        state="NC",
        postal="",
        lat=35.186389,
        lng=-80.912778,
        housenumber="",
        country="USA",
    ),
    "Toyota Center, Houston, Texas": SportsballGeocodeTuple(
        city="Houston",
        state="TX",
        postal="",
        lat=29.750833,
        lng=-95.362222,
        housenumber="1510",
        country="USA",
    ),
    "American Airlines Center, Dallas, Texas": AMERICAN_AIRLINES_ARENA,
    "Miami Arena": SportsballGeocodeTuple(
        city="Miami",
        state="FL",
        postal="",
        lat=25.781111,
        lng=-80.194722,
        housenumber="721",
        country="USA",
    ),
    "Al McGuire Center, Milwaukee, Wisconsin": SportsballGeocodeTuple(
        city="Milwaukee",
        state="WI",
        postal="53233",
        lat=43.039722,
        lng=-87.926389,
        housenumber="770",
        country="USA",
    ),
    "Orlando Arena": ORLANDO_ARENA,
    "Tokyo Metropolitan Gymnasium": SportsballGeocodeTuple(
        city="Tokyo",
        state="",
        postal="",
        lat=35.679694,
        lng=139.7125,
        housenumber="",
        country="Japan",
    ),
    "Target Center - Minneapolis, Minnesota - United States": TARGET_CENTER,
    "Thomas & Mack Center - Paradise, NV - United States": THOMAS_AND_MACK_CENTER,
    "Delta Center - Salt Lake City, Utah - United States": DELTA_CENTER,
    "Yokohama Arena": SportsballGeocodeTuple(
        city="Kanagawa",
        state="",
        postal="",
        lat=35.512389,
        lng=139.620056,
        housenumber="",
        country="Japan",
    ),
    "Anaheim Convention Center": SportsballGeocodeTuple(
        city="Anaheim",
        state="CA",
        postal="92802",
        lat=33.802455,
        lng=-117.919843,
        housenumber="800",
        country="USA",
    ),
    "TD Banknorth Garden": TD_GARDEN,
    "Amway Arena": ORLANDO_ARENA,
    "TD Garden - Boston, Massachusetts - United States": TD_GARDEN,
    "American Airlines Center - Dallas, Texas, USA - United States": AMERICAN_AIRLINES_ARENA,
    "FTX Arena": FTX_ARENA,
    "Rose Garden": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="",
        lat=45.531667,
        lng=-122.666667,
        housenumber="1",
        country="USA",
    ),
    "Toyota Center - Kennewick, Washington - United States": SportsballGeocodeTuple(
        city="Kennewick",
        state="WA",
        postal="",
        lat=46.22,
        lng=-119.217,
        housenumber="7016",
        country="USA",
    ),
    "Philips Arena": STATE_FARM_ARENA,
    "United Center - Chicago, Illinois - United States": UNITED_CENTER,
    "Wachovia Center": SPECTRUM,
    "New Orleans Arena": CAESARS_SUPERDOME,
    "Ball Arena - Denver, CO - United States": PEPSI_CENTRE,
    "Saitama Super Arena - Saitama, Japan - Japan": SportsballGeocodeTuple(
        city="Saitama",
        state="",
        postal="",
        lat=35.894889,
        lng=139.630831,
        housenumber="8",
        country="Japan",
    ),
    "Rogers Place - Edmonton, Alberta, Canada - Canada": SportsballGeocodeTuple(
        city="Edmonton",
        state="AL",
        postal="",
        lat=53.546944,
        lng=-113.497778,
        housenumber="10220",
        country="Canada",
    ),
    "Etihad Arena - Yas Bay Waterfront, Yas Island, Abu Dhabi - United Arab Emirates": SportsballGeocodeTuple(
        city="Abu Dhabi",
        state="",
        postal="",
        lat=24.4603,
        lng=54.604,
        housenumber="",
        country="UAE",
    ),
    "Gainbridge Fieldhouse - Indianapolis, Indiana - United States": GAINBRIDGE_FIELDHOUSE,
    "Fiserv Forum - Milwaukee, Wisconsin - United States": FISERV_FORUM,
    "Crypto.com Arena - Los Angeles, California, USA - United States": STAPLES_CENTRE,
    "Golden 1 Center - Sacramento, California - United States": GOLDEN_1_CENTER,
    "Moda Center, Portland, Oregon": SportsballGeocodeTuple(
        city="Portland",
        state="OR",
        postal="",
        lat=45.531667,
        lng=-122.666667,
        housenumber="1",
        country="USA",
    ),
    "United Center, Chicago, Illinois": UNITED_CENTER,
    "Rocket Mortgage Fieldhouse, Cleveland, Ohio": SportsballGeocodeTuple(
        city="Cleveland",
        state="OH",
        postal="",
        lat=41.496389,
        lng=-81.688056,
        housenumber="1",
        country="USA",
    ),
    "FedEx Forum, Memphis, Tennessee": FEDEX_FORUM,
    "Target Center, Minneapolis, Minnesota": TARGET_CENTER,
    "Kia Center, Orlando, Florida": SportsballGeocodeTuple(
        city="Orlando",
        state="FL",
        postal="",
        lat=28.539167,
        lng=-81.383611,
        housenumber="400",
        country="USA",
    ),
    "AccorHotels Arena, Paris, France": SportsballGeocodeTuple(
        city="Paris",
        state="Ile-de-France",
        postal="",
        lat=48.838611,
        lng=2.378611,
        housenumber="8",
        country="France",
    ),
    "Ball Arena, Denver, Colorado": PEPSI_CENTRE,
    "Crypto.com Arena, Los Angeles, California": STAPLES_CENTRE,
    "Paycom Center, Oklahoma City, Oklahoma": SportsballGeocodeTuple(
        city="Oklahoma City",
        state="OK",
        postal="",
        lat=35.463333,
        lng=-97.515,
        housenumber="100",
        country="USA",
    ),
    "Golden 1 Center, Sacramento, California": GOLDEN_1_CENTER,
    "Kaseya Center, Miami, Florida": KASEYA_CENTER,
    "Scotiabank Arena, Toronto, Canada": SCOTIABANK_ARENA,
    "Smoothie King Center, New Orleans, Louisiana": CAESARS_SUPERDOME,
    "TD Garden, Boston, Massachusetts": TD_GARDEN,
    "Frost Bank Center, San Antonio, Texas": SportsballGeocodeTuple(
        city="San Antonio",
        state="TX",
        postal="",
        lat=29.426944,
        lng=-98.4375,
        housenumber="1",
        country="USA",
    ),
    "Intuit Dome, Inglewood, California": SportsballGeocodeTuple(
        city="Inglewood",
        state="CA",
        postal="",
        lat=33.9451,
        lng=-118.3431,
        housenumber="3930",
        country="USA",
    ),
    "Delta Center, Salt Lake City, Utah": DELTA_CENTER,
    "AT&T Center, San Antonio, Texas": ATT_CENTER,
    "FTX Arena, Miami, Florida": FTX_ARENA,
    "Vivint Smart Home Arena, Salt Lake City, Utah": VIVINT_ARENA,
    "Chesapeake Energy Arena, Oklahoma City, Oklahoma": CHESAPEAKE_ENERGY_ARENA,
    "The Arena, Bay Lake, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "HP Field House, Bay Lake, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Mexico City Arena, Mexico City, Mexico": SportsballGeocodeTuple(
        city="Mexico City",
        state="",
        postal="04650",
        lat=19.496309,
        lng=-99.175429,
        housenumber="",
        country="Mexico",
    ),
    "Amway Center, Orlando, Florida": ORLANDO_ARENA,
    "Phoenix Suns Arena, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "Quicken Loans Arena, Cleveland, Ohio": QUICKEN_LOANS_ARENA,
    "STAPLES Center, Los Angeles, California": STAPLES_CENTRE,
    "Bankers Life Fieldhouse, Indianapolis, Indiana": GAINBRIDGE_FIELDHOUSE,
    "AmericanAirlines Arena, Miami, Florida": KASEYA_CENTER,
    "Amalie Arena, Tampa, Florida": SportsballGeocodeTuple(
        city="Tampa",
        state="FL",
        postal="",
        lat=27.942778,
        lng=-82.451944,
        housenumber="401",
        country="USA",
    ),
    "Pepsi Center, Denver, Colorado": PEPSI_CENTRE,
    "Visa Athletic Center, Bay Lake, Florida": ESPN_WIDE_WORLD_OF_SPORTS_COMPLEX,
    "Dunn–Oliver Acadome, Montgomery, Alabama": DUNN_OLIVER_ACADOME,
    "Talking Stick Resort Arena, Phoenix, Arizona": AMERICA_WEST_ARENA,
    "Oracle Arena, Oakland, California": OAKLAND_ARENA,
    "The O2 Arena, London, United Kingdom": SportsballGeocodeTuple(
        city="London",
        state="",
        postal="SE10",
        lat=51.5029,
        lng=0.0032,
        housenumber="",
        country="UK",
    ),
    "Air Canada Centre, Toronto, Canada": SCOTIABANK_ARENA,
    "BMO Harris Bradley Center, Milwaukee, Wisconsin": BRADLEY_CENTER,
    "Philips Arena, Atlanta, Georgia": STATE_FARM_ARENA,
    "UW–Milwaukee Panther Arena, Milwaukee, Wisconsin": MILWAUKEE_ARENA,
    "Dreamstyle Arena, Albuquerque, New Mexico": THE_PIT,
    "Tom Gola Arena, Philadelphia, Pennsylvania": JOHN_GLASER_ARENA,
    "Texas A&M–Commerce Field House, Commerce, Texas": TEXAS_AM_COMMERCE_FIELD_HOUSE,
    "Detroit, Michigan": SportsballGeocodeTuple(
        city="Detroit",
        state="MI",
        postal="",
        lat=42.333333,
        lng=-83.05,
        housenumber="",
        country="USA",
    ),
    "Rec Hall, University Park, Pennsylvania": SportsballGeocodeTuple(
        city="University Park",
        state="PA",
        postal="16802",
        lat=40.79578,
        lng=-77.869399,
        housenumber="",
        country="USA",
    ),
    "Dallas, Texas": SportsballGeocodeTuple(
        city="Dallas",
        state="TX",
        postal="",
        lat=32.779167,
        lng=-96.808889,
        housenumber="",
        country="USA",
    ),
}


def _create_google_address_model(
    query: str, session: requests_cache.CachedSession, dt: datetime.datetime
) -> AddressModel:
    g = _CACHED_GEOCODES.get(query)
    if g is None:
        logging.warning("Failed to find query: %s", query)
        g = geocoder.google(query, session=session)
        _CACHED_GEOCODES[query] = g
    latitude = g.lat
    longitude = g.lng
    weather_model = None
    tz = "UTC"
    if latitude is not None and longitude is not None:
        tf = TimezoneFinder()
        timezone = tf.timezone_at(lng=longitude, lat=latitude)
        if timezone is not None:
            tz = timezone
        weather_model = create_mutli_weather_model(
            session,
            latitude,
            longitude,
            dt,  # pyright: ignore
            tz,
        )
    return AddressModel(
        city=g.city,
        state=g.state,
        zipcode=g.postal,
        latitude=latitude,
        longitude=longitude,
        housenumber=g.housenumber,
        weather=weather_model,  # pyright: ignore
        timezone=tz,
        country=g.country,
    )


@MEMORY.cache(ignore=["session"])
def _cached_create_google_address_model(
    query: str, session: requests_cache.CachedSession, dt: datetime.datetime
) -> AddressModel:
    return _create_google_address_model(query, session, dt)


def create_google_address_model(
    query: str, session: requests_cache.CachedSession, dt: datetime.datetime
) -> AddressModel:
    """Create address model from google."""
    if not pytest_is_running.is_running() and dt < datetime.datetime.now().replace(
        tzinfo=dt.tzinfo
    ) - datetime.timedelta(days=7):
        return _cached_create_google_address_model(query, session, dt)
    with session.cache_disabled():
        return _create_google_address_model(query, session, dt)
